// Generated by dts-bundle-generator v6.2.0

/// <reference types="webxr" />

import TWEEN from '@tweenjs/tween.js';
import { Group as TweenGroup, Tween } from '@tweenjs/tween.js';
import { Dictionary } from 'lodash';
import { BufferGeometry, Camera, Group, Intersection, Object3D, Quaternion, Scene, Vector2, Vector3 } from 'three';

/**
 * View orientation defined by cameras elevation and azimuth angle in radians.
 */
export interface ViewOrientationInterface {
	/**
	 * Camera azimuth angle in radians.
	 */
	lon: number;
	/**
	 * Camera elevation angle in radians.
	 */
	lat: number;
}
/**
 * Mouse event coordinates
 */
export interface MouseEventCoordinatesInterface {
	/**
	 * X coordinate of the mouse position [px]
	 */
	x: number;
	/**
	 * Y coordinate of the mouse position [px]
	 */
	y: number;
	/**
	 * Original mouse event
	 */
	event: MouseEvent;
}
export interface ViewportDimensionsInterface {
	/**
	 * Left edge of viewport [0…1], where 0 is left
	 */
	left: number;
	/**
	 * Bottom edge of viewport [0..1], where 0 is bottom
	 */
	bottom: number;
	/**
	 * Width of viewport [0..1]
	 */
	width: number;
	/**
	 * Height of viewport [0..1]
	 */
	height: number;
}
/**
 * A viewport is a sub-area of the entire rendering surface, see
 * https://threejs.org/docs/#api/renderers/WebGLRenderer.setViewport
 */
export interface ViewportInterface extends ViewportDimensionsInterface {
	/**
	 * Name of the viewport
	 */
	name: string;
	/**
	 * Camera used for rendering
	 */
	camera: Camera;
	/**
	 * Set viewport offset and size on screen
	 *
	 * @param left Left edge of viewport [0..1], where 0 is left
	 * @param bottom Bottom edge of viewport [0..1], where 0 is bottom
	 * @param width Width of viewport [0..1]
	 * @param height Height of viewport [0..1]
	 */
	setDimensions(left: number, bottom: number, width: number, height: number): void;
	/**
	 * Check if provided screen coordinate is within the viewport
	 *
	 * @param x Screen-space coordinate relative to top-left corner of viewport [px]
	 * @param y Screen-space coordinate relative to top-left corner of viewport [px]
	 * @returns {boolean}
	 */
	contains(x: number, y: number): boolean;
}
export declare type OnContextMenuResult = ContextMenuEntryInterface | ContextMenuEntryInterface[] | boolean | undefined;
export interface ContextMenuHandlerInterface {
	onContextMenu?(pos: MouseEventCoordinatesInterface, instanceId?: number): OnContextMenuResult | Promise<OnContextMenuResult>;
}
/**
 * A context menu entry with a name and an icon that invokes the callback function when clicked.
 */
export interface ContextMenuEntryInterface {
	/**
	 * Specify the human readable name of the command in the menu.
	 * This is used as the label for the option
	 */
	name: string;
	/**
	 * Specifies the icon class to set for the item
	 */
	icon: string;
	/**
	 * Specifies the callback to execute if clicked on
	 */
	callback: Function;
	/**
	 * Key for the entry, only one entry is shown per unique key
	 */
	key?: string;
}
/**
 * Objects that are stored as resources in the database inherit from this interface.
 */
export interface RepositoryObjectInterface {
	/**
	 * Entity id number
	 */
	readonly id: number;
}
/**
 * A Location represents a point within NavVis IVION space.
 */
export interface LocationInterface extends RepositoryObjectInterface {
	/**
	 * Location in the local coordinate system (i.e. the site coordinate system).
	 */
	location: Vector3;
	/**
	 * Orientation in the local coordinate system (i.e. the site coordinate system).
	 */
	orientation: Quaternion;
	/**
	 * Location in the dataset's coordinate system
	 */
	datasetLocation: Vector3;
	/**
	 * Orientation in the dataset's coordinate system
	 */
	datasetOrientation: Quaternion;
}
export type CoordinateTypes = number[][][] | number[][] | number[] | Vector3;
export interface GeometryRest {
	coordinates: CoordinateTypes;
	type: string;
}
export interface GeoJsonGeometry {
	toGeometry(): BufferGeometry;
	getFirstPoint(): Vector2;
}
export declare enum SiteModelType {
	BUILDING = "BUILDING",
	FLOOR = "FLOOR",
	ROOM = "ROOM",
	FREE_SPACE_NAVIGATION = "FREE_SPACE_NAVIGATION",
	CUSTOM = "CUSTOM"
}
/**
 * [Site model](../../../help/glossary.html#term-site) entities are geometric boundaries
 * that represent any kind of spatial sectioning.
 *
 * These entities may represent a building, a floor, or even an open space. These entities
 * can also be linked hierarchically via parent/children associations.
 */
export interface SiteModelEntityInterface {
	/**
	 * Parent [site model](../../../help/glossary.html#term-site) entity.
	 */
	parent: SiteModelEntityInterface;
	/**
	 * Children [site model](../../../help/glossary.html#term-site) entities. A collection of
	 * sub-entities whose parent is the current entity.
	 */
	children: SiteModelEntityInterface[];
	/**
	 * Key-value pairs for storing additional user data associated to the [site model](../../../help/glossary.html#term-site) entity.
	 */
	attributes: Dictionary<string>;
	/**
	 * The display name for the [site model](../../../help/glossary.html#term-site) entity.
	 */
	name: string;
	/**
	 * Type for the [site model](../../../help/glossary.html#term-site) entity.
	 * This can be used to structure site model entities.
	 */
	type: SiteModelType;
	/**
	 * The calculated center point of the [site model](../../../help/glossary.html#term-site) entity
	 * polygon.
	 */
	readonly center: Vector3;
	/**
	 * The height between the lower and upper planes of the polygon on the Z-axis [m].
	 */
	readonly height: number;
	/**
	 * The geometric polygon structure.
	 */
	polygon: GeoJsonGeometry;
	/**
	 * The lowest numeric value of the Z-coordinates of the entire
	 * [site model](../../../help/glossary.html#term-site) entity. This value is
	 * relative to the local coordinate origin.
	 */
	zMin: number;
	/**
	 * The highest numeric value of the Z-coordinates of the entire
	 * [site model](../../../help/glossary.html#term-site) entity. This value is
	 * relative to the local coordinate origin.
	 */
	zMax: number;
	/**
	 * Calculates the floor 2-dimensional size of the
	 * [site model](../../../help/glossary.html#term-site) entity polygon [m²].
	 */
	readonly area: number;
	/**
	 * Calculates the 3-dimensional size of the
	 * [site model](../../../help/glossary.html#term-site) entity polygon [m³].
	 */
	readonly volume: number;
}
/**
 * An Image is the panoramic visual representation of a specific point in space.
 *
 * Images can be thought of as locations that have visual data.
 */
export interface ImageInterface extends LocationInterface {
	/**
	 * File name identifier. An image is saved to disk as various degrees of
	 * resolution and under different directories (for each resolution). The
	 * `fileId` identifies the related files across directories.
	 */
	readonly fileId: string;
	/**
	 * File path for files of the image. Each [image resolution](https://en.wikipedia.org/wiki/Image_resolution)
	 * is contained within individual relative subdirectories.
	 */
	readonly filePath: string;
	/**
	 * Display or hide the location marker in the panoramic and map views. Hiding images can reduce network traffic.
	 */
	hidden: boolean;
	/**
	 * [Site model](../../../help/glossary.html#term-site) entity in which the image is located.
	 */
	siteModelEntity: SiteModelEntityInterface;
}
/**
 * PoiTypeGroups are categorical groups for {@link PoiTypeInterface}s.
 *
 * These categorical groups function primarily as information organization.
 * PoiTypeGroups are also associated to security permissions.
 */
export interface PoiTypeGroupInterface extends RepositoryObjectInterface {
	/**
	 * The name of the group. This name appears in UI elements.
	 * It is an associative array of strings, whose keys are ISO 15897 locale tags.
	 */
	readonly name: Dictionary<string>;
}
/**
 * A POI type is a categorical object for points of interest ({@link PoiInterface})
 *
 */
export interface PoiTypeInterface extends RepositoryObjectInterface {
	/**
	 * Get the POI type's icon URL. Default icon is supplied if none defined.
	 * @return {string} URL to the icon.
	 */
	readonly icon: string;
	/**
	 * Short summary text. It is an associative array of HTML text, whose keys are ISO 15897 locale tags.
	 */
	readonly name: Dictionary<string>;
	/**
	 * Categorical group for the POI type
	 */
	poiTypeGroup: PoiTypeGroupInterface;
	/**
	 * Maximum zoom level until POI icons of this type is displayed in map view.
	 * The unit for this value is pixels-per-meter. When a represented meter
	 * surpasses this number of pixels, the POI of this type are not displayed.
	 */
	readonly visibilityZoomMax?: number;
	/**
	 * Minimum zoom level until POI icons of this type is displayed in map view.
	 * The unit for this value is pixels-per-meter. When a represented meter
	 * shrinks under this number of pixels, the POI of this type are not displayed.
	 */
	readonly visibilityZoomMin?: number;
}
/**
 * A set of properties describing the preferred view on the 3D object.
 */
export interface PointOfViewInterface {
	/**
	 * Global coordinates describing viewing location.
	 */
	location: Vector3;
	/**
	 * Preferred view direction.
	 */
	orientation: Quaternion;
	/**
	 * Preferred field of view [deg].
	 */
	fov: number;
	/**
	 * Id of the image defining viewing location (optional).
	 */
	imageId: number;
}
/**
 * A [POI](../../../help/glossary.html#term-point-of-interest) represents any type of informational
 * or functional object in a space.
 *
 * The interface provides attributes for storing data that are associated to a
 * real-world object. The {@link titles} attribute is intended to store a brief
 * summary of the POI, which is displayed in the 2D and 3D scenes as icons. For
 * larger bodies of information, the {@link descriptions} attribute can store
 * large HTML-based content. Additional data or metadata can be stored in the
 * {@link customData} attribute; this attribute can be used for processing
 * within customized logic.
 *
 * {@link poiType} is a {@link PoiTypeInterface} that the POI is categorized under.
 *
 * The {@link icon} and {@link importance} attributes are used to control the visual
 * representation and rendering of the POI.
 */
export interface PoiInterface extends LocationInterface {
	/**
	 * Supplementary custom data associated to the POI.
	 */
	customData: string;
	/**
	 * Supplementary custom key-value pairs associated to the POI.
	 */
	attributes: Dictionary<string>;
	/**
	 * Large content text. It is an associative array of HTML text, whose keys are ISO 15897 locale
	 * tags.
	 */
	descriptions: Dictionary<string>;
	/**
	 * Large content text of the the POI in the currently set language.
	 */
	description: string;
	/**
	 * Get the POI's icon URL. Default icon is supplied if none defined.
	 */
	icon: string;
	/**
	 * Non-unique numeric importance value. Used to control POI icon visual cluttering in map view.
	 */
	importance: number;
	/**
	 * POI type object.
	 */
	poiType: PoiTypeInterface;
	/**
	 * Short summary text. It is an associative array of HTML text, whose keys are ISO 15897 locale
	 * tags.
	 */
	titles: Dictionary<string>;
	/**
	 * Short summary text of the POI in the currently set language.
	 */
	title: string;
	/**
	 * Object describing preferred view on the POI.
	 * It is not possible to directly set the POV object on POIs, this must be done using the
	 * {@link setPointOfView} method.
	 */
	pov: PointOfViewInterface;
	/**
	 * A timestamp of last activity (creation or update of the POI) in UNIX time.
	 * Not set for POIs updated before the introduction of this property.
	 */
	updatedDate?: Date;
	/**
	 * Creates a copy of the POI entity.
	 *
	 * @param {RepositoryObject} source POI entity
	 * @param {boolean} excludeTransients whether temporary fields should be excluded from the copy
	 * @param {boolean} excludeId whether the ID field should be excluded from the copy, thus saving
	 * it won't overwrite the source entity.
	 *
	 * @returns {PoiInterface}
	 */
	copy(source: PoiInterface, excludeTransients?: boolean, excludeId?: boolean): PoiInterface;
	/**
	 * Set the {@link pov} point of view defined by the provided parameters as the
	 * default one that will be used when moving to this POI.
	 *
	 * @param {Vector3} location Mandatory parameter. Defines the position where the camera will be
	 * moved to when point cloud mode is active, or when panorama mode is active and no imageId is
	 * given
	 * @param {Quaternion} orientation Mandatory parameter. Defines the viewing direction that will
	 * be used once moved to the position of this POI.
	 * @param {number} fov Optional parameter. If provided, this will be the value used for the fov
	 * once moved to the POI. If not provided, the current fov will be maintained.
	 * @param {number} imageId Optional parameter. If provided, this will define the position where
	 * the camera moves when moving to the POI while panorama mode is active.
	 */
	setPointOfView(location: Vector3, orientation: Quaternion, fov?: number, imageId?: number): void;
}
export type TransitionStartHandler = 
/**
 * Signal handler that is called when a transition to a new location is started
 *
 * @param event Object with information about the transition
 */
(event: TransitionStartEventInterface) => void;
/**
 * Event information about the start of a transition to a new location
 */
export interface TransitionStartEventInterface {
	/**
	 * Image where the transition started
	 */
	readonly previousImage?: ImageInterface;
	/**
	 * Image at target location
	 */
	readonly image?: ImageInterface;
	/**
	 * Optional [site model](../../../help/glossary.html#term-site) entity if the transition was
	 * originally triggered by one.
	 */
	readonly siteModelEntity?: SiteModelEntityInterface;
	/**
	 * Optional [POI](../../../help/glossary.html#term-point-of-interest) if the transition was
	 * originally triggered by one.
	 */
	readonly poiEntity?: PoiInterface;
}
export type TransitionEndHandler = 
/**
 * Signal handler that is called when a transition to a new location has completed
 *
 * @param event Object with information about the transition
 */
(event: TransitionEndEventInterface) => void;
/**
 * Event information about the end of a transition to a new location
 */
export interface TransitionEndEventInterface {
	/**
	 * Image where the transition started
	 */
	readonly previousImage?: ImageInterface;
	/**
	 * Image at target location
	 */
	readonly image?: ImageInterface;
	/**
	 * Optional [site model](../../../help/glossary.html#term-site) entity if the transition was
	 * originally triggered by one.
	 */
	readonly siteModelEntity?: SiteModelEntityInterface;
	/**
	 * Optional [POI](../../../help/glossary.html#term-point-of-interest) if the transition was
	 * originally triggered by one.
	 */
	readonly poiEntity?: PoiInterface;
}
/**
 * A scene layer that displays objects in the 3D scene.
 * This interface serves as a template to construct your own custom data layers. Public methods
 * described in this class act as callbacks to particular events occurring in the view (Main or Map view)
 * to which the scene layer is added.
 *
 * Note:
 * The mouse or touch event callbacks can also be added to individual THREE.Mesh objects inside data layers.
 * In case of multiple callbacks, Mesh objects are prioritized over data layers.
 * For a complete reference of all of the events supported on THREE.Mesh, see: {@link MouseEventReceiverInterface}
 */
export interface SceneLayerInterface extends ContextMenuHandlerInterface {
	/**
	 * Target viewport
	 */
	targetViewport: ViewportInterface;
	/**
	 * Layer visibility
	 */
	visible: boolean;
	/**
	 * Called before rendering
	 *
	 * @param camera Camera used to render the view
	 */
	onBeforeRender(camera: Camera): void;
	/**
	 * Called before rendering a viewport
	 *
	 * @param viewport Viewport where rendering takes place
	 */
	onBeforeRenderViewport(viewport: ViewportInterface): void;
	/**
	 * Called after rendering of all viewports
	 *
	 * @param camera Camera used to render the view
	 */
	onAfterRender(camera: Camera): void;
	/**
	 * Called after rendering of a viewport
	 *
	 * @param viewport Viewport where rendering took place
	 */
	onAfterRenderViewport(viewport: ViewportInterface): void;
	/**
	 * Called when a location transition is started
	 *
	 * @param event Transition event
	 */
	onTransitionStart(event: TransitionStartEventInterface): void;
	/**
	 * Called after location transition has completed
	 *
	 * @param event Transition event
	 */
	onTransitionEnd(event: TransitionEndEventInterface): void;
	/**
	 * Called shortly after the camera has stopped moving
	 *
	 * @param {Promise<void>} asyncWork Promise which blocks until the {@link AbstractViewInterface} has
	 * completed any asynchronous work, independent of whether it rejects or resolves.
	 */
	onCameraMoveEnd(asyncWork: Promise<void>): void;
	/**
	 * Called when a key is pressed down
	 *
	 * @param event Key event data
	 * @returns {boolean} Return true to consume the event, false to pass it on to other layers
	 */
	onKeyDown(event: KeyboardEvent): boolean;
	/**
	 * Called when a key is released
	 *
	 * @note released keys on a physical keyboard connected to an iOS device do not fire the keyup event
	 *
	 * @param event Key event data
	 * @returns {boolean} Return true to consume the event, false to pass it on to other layers
	 */
	onKeyUp(event: KeyboardEvent): boolean;
	/**
	 * Called for mouse clicks and taps
	 *
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @param cursorPos The 3D cursor position at the location of the click.
	 * @returns {boolean} Return true to consume the event, false to pass it on
	 */
	onClick(pos: MouseEventCoordinatesInterface, cursorPos?: Vector3): boolean;
	/**
	 * Called for double clicks and double taps
	 *
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @returns {boolean} Return true to consume the event, false to pass it on
	 */
	onDoubleClick(pos: MouseEventCoordinatesInterface): boolean;
	/**
	 * Called for click-and-hold and touch-and-hold
	 *
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @returns {boolean} Return true to consume the event, false to pass it on
	 */
	onHold(pos: MouseEventCoordinatesInterface): boolean;
	/**
	 * Called when the mouse is moved
	 *
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 */
	onMouseMove(pos: MouseEventCoordinatesInterface): void;
	/**
	 * Called when the mouse wheel is used
	 *
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @param {number} delta Number of wheel ticks, positive for scrolling down, negative for up
	 * @returns {boolean} Return true to consume the event, false to pass it on
	 */
	onMouseWheel(pos: MouseEventCoordinatesInterface, delta: number): boolean;
	/**
	 * Called when the context menu is about to be shown
	 *
	 * Return context menu items from this method to add them to the context menu.
	 * Return ``undefined`` (or do not implement the method) if you do not want to add an entry from the specific layer.
	 * Return false to prevent the context menu from opening.
	 *
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @returns {OnContextMenuResult} List of context menu items
	 */
	onContextMenu(pos: MouseEventCoordinatesInterface): OnContextMenuResult | Promise<OnContextMenuResult>;
}
export interface ScreenshotDataInterface {
	/**
	 * Content of the view window as a data URI encoded image.
	 */
	data: string;
	/**
	 * Width of the view window.
	 */
	width: number;
	/**
	 * Height of the view window.
	 */
	height: number;
}
/**
 * Base interface for 3D views.
 *
 * The view provides a layer mechanism to plug in modules that add 3D objects to the view.
 * Layers can define events that are called on various occasions, e.g., when the user changes
 * the current location or moves the mouse. Layers are responsible for managing the Three.JS
 * objects below their scene node. To simplify user input handling, meshes added to the scene can
 * define handlers for events like clicks, mouse over, mouse out, dragging, etc.
 *
 * This interface provides a mechanism to render-on-demand, i.e., only when scene contents changed.
 * Whenever the scene or objects are modified (e.g. by a layer), a call to {@link invalidateScene}
 * causes the scene to be rendered. {@link invalidateScene} can be called repeatedly, however rendering
 * will only occur at a fixed rate.
 *
 * For tweening, the view provides the methods {@link watchTween} and {@link forgetTween}. As long as tweens
 * are watched by the view, the rendering loop will stay active. To use this mechanism, call
 * {@link watchTween} when you start it and {@link forgetTween} when it completes.
 */
export interface AbstractViewInterface {
	/**
	 * Object that contains items that will be rendered in the view.
	 * For more information [ThreeJS.Scene](https://threejs.org/docs/index.html#api/en/scenes/Scene)
	 */
	scene: Scene;
	/**
	 * Adds a scene layer to the 3D view.
	 * Note: see the example on how to add a custom data layer in the 'Developer Guide' section.
	 *
	 * @param layer Scene layer to add
	 */
	addToScene(layer: SceneLayerInterface): void;
	/**
	 * Invalidates the scene so that it is rendered. Call this method whenever things
	 * happen that modify the appearance of the scene (e.g. a texture download finishes).
	 *
	 * @param callback callback to be run after scene has been rendered
	 */
	invalidateScene(callback?: () => void): void;
	/**
	 * Create a tween that is added to the watch list when started and removed from the watch list
	 * when it completes or when it is stopped.
	 *
	 * As long as at least one tween is watched, the view will render at a fixed frame rate.
	 *
	 * @param object The object to tween. This is passed on to the Tween constructor.
	 * @param group The tween group. This is passed on to the Tween constructor.
	 * @return The tween with onStart(), onStop() and onComplete() callbacks installed.
	 */
	createWatchedTween<T>(object: T, group?: TweenGroup | false): Tween<T>;
	/**
	 * Add a tween to the watch list. Call this when you start a tween.
	 * As long as at least one tween is watched, the view will render at a fixed frame rate.
	 *
	 * @param tween Tween to watch
	 */
	watchTween(tween: Tween<unknown>): void;
	/**
	 * Remove a tween from the watch list. Call this from tween's <pre>onComplete()</pre> and
	 * <pre>onStop()</pre> methods.
	 *
	 * @param tween Tween to remove
	 */
	forgetTween(tween: Tween<unknown>): void;
	/**
	 * Close context menu
	 */
	closeContextMenu(): void;
	/**
	 * Get the first viewport
	 */
	getDefaultViewport(): ViewportInterface;
	/**
	 * Center all viewports on the specified location
	 *
	 * @param {Vector3} position Position to center view on
	 * @param {number} frustumDepth Adjust the frustum size of orthographic cameras so that far - near = frustumDepth
	 */
	centerOn(position: Vector3, frustumDepth?: number): void;
	/**
	 * Unproject screen-space coordinates (relative to the viewport, i.e. (0,0) is
	 * the upper left corner of the rendering DIV).
	 *
	 * @param x X coordinate in screen-space
	 * @param y Y coordinate in screen-space
	 * @param z Z coordinate in screen-space (defaults to 1 if not provided)
	 * @param viewport The viewport to use for unprojection
	 *
	 * @returns {Vector3} Unprojected coordinates (local coordinates)
	 */
	unprojectScreenCoordinates(x: number, y: number, z?: number, viewport?: ViewportInterface): Vector3;
	/**
	 * Unproject screen-space coordinates given as input event.
	 *
	 * @note This method is viewport-aware and takes care of the extra transformation.
	 *
	 * @param event Hammer.JS event data
	 * @param z Z coordinate in screen-space (defaults to 1 if not provided)
	 *
	 * @returns {Vector3} Unprojected coordinates (local coordinates)
	 */
	unprojectEvent(event: MouseEvent, z?: number): Vector3;
	/**
	 * Find 3D objects under the mouse cursor.
	 *
	 * @note This method is viewport-aware and takes care of the extra transformation.
	 *
	 * @param pos Mouse position
	 * @returns {Intersection[]} Intersections with mouse cursor
	 */
	getObjectsUnderCursor(pos: MouseEventCoordinatesInterface): Intersection[];
	/**
	 * Get 3D position of specified screen coordinates assuming a ground plane at given height
	 *
	 * @note This method is viewport-aware and takes care of the extra transformation.
	 *
	 * @param x Screen X coordinate
	 * @param y Screen Y coordinate
	 * @param z Z coordinate of ground plane. Can be undefined.
	 * @param viewport Viewport to use (optional)
	 *
	 * @returns {Vector3} 3D position of mouse or gesture event on the plane (or null)
	 *
	 * @note Unprojects the screen coordinates and intersects the ray with a plane with normal
	 *        (0,0,1) at specified height in order to get the 3D point coordinates on the plane.
	 *
	 * @note If z is undefined, the plane is assumed to be 1 unit away from the camera position in
	 *       the direction the camera is facing.
	 */
	getPositionOnGroundPlane(x: number, y: number, z: number, viewport?: ViewportInterface): Vector3;
	/**
	 * @returns {MouseEventCoordinatesInterface} Last mouse position
	 */
	getLastMousePosition(): MouseEventCoordinatesInterface;
	/**
	 * Creates a new scene group object
	 */
	createSceneGroup(): Object3D;
	/**
	 * Takes a screenshot of the view.
	 *
	 * @param {string} mimeType MIME type of the returned data, defaults to `image/jpeg`.
	 * @param {number} quality Image quality that will be passed on to the [HTMLCanvasElement.toDataURL](https://developer.mozilla.org/en-US/docs/Web/API/HTMLCanvasElement/toDataURL) method.
	 *
	 * @returns {ScreenshotDataInterface} Data of the screenshot, including info about its dimensions.
	 */
	getScreenshot(mimeType?: string, quality?: number): ScreenshotDataInterface;
	/**
	 * @note If there are multiple viewports, this shall return the camera for the default one
	 * @returns {Camera} The camera used to render the view
	 */
	getCamera(): Camera;
}
declare class Point implements GeometryRest {
	coordinates: Vector3;
	type: string;
	constructor(coord: Vector3);
}
export interface CursorDataInterface {
	/**
	 * Coordinates of the cursor in WGS 84. Do not use, use the location field instead.
	 * @deprecated
	 */
	geometry: Point;
	/**
	 * Coordinates of the cursor in the site coordinate system.
	 */
	location: Vector3;
	/**
	 * Orientation of the cursor in the site coordinate system.
	 */
	orientation: Quaternion;
	/**
	 * Coordinates of the cursor in the dataset coordinate system. Can be undefined when in the map view.
	 */
	datasetOrientation: Quaternion;
	/**
	 * Orientation of the cursor in the dataset coordinate system. Can be undefined when in the map view.
	 */
	datasetLocation: Vector3;
	/**
	 * The dataset id. Can be undefined when in the map view.
	 */
	datasetId: number;
}
export interface MainViewInterface extends AbstractViewInterface {
	/**
	 * Current view orientation
	 */
	currViewingDir: ViewOrientationInterface;
	/**
	 * Get the field of view of the default viewport
	 *
	 * @returns {number} Field of view [degrees]
	 */
	getFov(): number;
	/**
	 * Returns the LocationMarker layer
	 *
	 * @returns {SceneLayerInterface} LocationMarker layer if found, undefined otherwise
	 */
	getLocationMarkerLayer(): SceneLayerInterface;
	/**
	 * Returns the POI layer
	 *
	 * @returns {SceneLayerInterface} POI layer if found, undefined otherwise
	 */
	getPoiLayer(): SceneLayerInterface;
	/**
	 * Returns the Route layer
	 *
	 * @returns {SceneLayerInterface} Route layer if found, undefined otherwise
	 */
	getRouteLayer(): SceneLayerInterface;
	/**
	 * Returns the Cursor layer
	 *
	 * @returns {SceneLayerInterface} Cursor layer if found, undefined otherwise
	 */
	getCursorLayer(): SceneLayerInterface;
	/**
	 * Return the currently active image.
	 * @note The image can be ``undefined``.
	 *
	 * @returns {ImageInterface} Currently active image
	 */
	getImage(): ImageInterface;
	/**
	 * Updates the viewing direction
	 *
	 * @param {ViewOrientationInterface} orientation View orientation
	 */
	updateOrientation(orientation: ViewOrientationInterface): void;
	/**
	 * Set the field of view of the default viewport
	 *
	 * @param fov Field of view [degrees]
	 */
	updateFov(fov: number): void;
	/**
	 * Retrieves data about the current cursor position in this view.
	 *
	 * @return {CursorDataInterface} Data about the current cursor position
	 */
	getCurrentCursorPosition(): CursorDataInterface;
}
/**
 * Icon info
 */
export interface IconInfoInterface {
	/**
	 * Class applied to the icon element in the DOM. Can be used to show icons from font libraries,
	 * e.g. 'material-icons', 'fa fa-magic', 'glyphicon-trash'.
	 */
	className: string;
	/**
	 * Icon ligature for icon fonts supporting it, e.g. 'explore' in Material Icons
	 * (http://google.github.io/material-design-icons).
	 */
	ligature: string;
	/**
	 * Path to the icon file, e.g. 'hamburger.svg' (absolute or relative to the embedding page).
	 * This also supports Data URIs.
	 */
	path: string;
}
/**
 * Item of the side menu
 */
export interface SidebarMenuItemInterface {
	/**
	 * Title displayed in the menu
	 */
	title: string;
	/**
	 * Info of an icon displayed in the menu
	 */
	icon: IconInfoInterface;
	/**
	 * Condition of the item's visibility
	 */
	isVisible: () => boolean;
	/**
	 * Path to the menu template (absolute or relative)
	 */
	template?: string;
	/**
	 * Class applied to the menu item element in the DOM
	 */
	getClass?: () => string;
	/**
	 * Order of the item inside the side menu. A lower value goes to the top.
	 */
	order?: number;
	/**
	 * Action performed when leaving the menu item (going back, switching items, closing menu).
	 * Returning `true` blocks an actual side menu action.
	 */
	onExit?: () => boolean;
	/**
	 * Action performed when clicking the menu item
	 */
	onClick?: () => void;
	/**
	 * Condition of the preview icon's visibility
	 */
	isPreviewIconVisible?: () => boolean;
	/**
	 * Child items
	 */
	items: SidebarMenuItemInterface[];
	/**
	 * Whether or not the menu item should be fullscreen
	 */
	isFullscreen: boolean;
}
export declare enum SortableField {
	ID = "ID",
	IMPORTANCE = "IMPORTANCE",
	FILE_ID = "FILE_ID"
}
export declare enum SortOrder {
	ASCENDING = "ASC",
	DESCENDING = "DESC"
}
/**
 * The common fields every filter request contain.
 */
export interface RestFilterInterface {
	/**
	 * Select for items associated to given dataset IDs.
	 */
	datasetIds: number[];
	/**
	 * Bounding box lower X.
	 */
	xMin: number;
	/**
	 * Bounding box upper X.
	 */
	xMax: number;
	/**
	 * Bounding box upper Y.
	 */
	yMax: number;
	/**
	 * Bounding box lower Y.
	 */
	yMin: number;
	/**
	 * Select for items at or near X coordinate.
	 */
	x: number;
	/**
	 * Select for items at or near Y coordinate.
	 */
	y: number;
	/**
	 * Select for items at or near Z coordinate.
	 */
	z: number;
	/**
	 * Limit the amount of items to retrieve.
	 */
	limit: number;
	/**
	 * Skip the specified number of items.
	 */
	offset: number;
	/**
	 * Distance from given {@link y}, {@link x}, and {@link z} to select items [m].
	 */
	radius: number;
	/**
	 * Select for items associated to given  IDs. Pass a single-item array
	 * containing `undefined` to retrieve items with no Site Model Entity.
	 */
	siteModelEntityIds: (number | "")[];
	/**
	 * Sort by given field.
	 */
	sortBy: SortableField;
	/**
	 * Direction of sort priority.
	 */
	sortOrder: SortOrder;
	/**
	 * Regularly subsample the list of items returned.
	 */
	step: number;
}
/**
 * The RestRepository retreives resources from the database through the REST API.
 *
 * A full list of resources can be fetched by calling {@link findAll} and a specific
 * resource by calling {@link findOne}.
 */
export interface RestRepositoryInterface<T> {
	/**
	 * Factory method. Creates and returns a new empty instance of the entity.
	 * @returns An instance of the entity.
	 */
	create(): T;
	/**
	 * Gets all repository items. The cached data will be returned if the data has been fetched
	 * before. Using the forceFetch parameter, a user can order a fresh copy to be fetched from the
	 * server.
	 * @param forceFetch Whether to bypass the cache and retrieve a fresh copy from the server.
	 * @returns Promise with the repository items.
	 */
	findAll(forceFetch?: boolean): Promise<T[]>;
	/**
	 * Get one repository item by id. The cached data will be returned if the data has been
	 * fetched before. Use the forceFetch parameter to retrieve a fresh copy from the server.
	 * In case a new record is fetched, the data and dataMap will be updated accordingly.
	 * @param id Identifier of the repository item
	 * @param forceFetch Whether to bypass the cache and retrieve a fresh copy from the server.
	 */
	findOne(id: number, forceFetch?: boolean): Promise<T>;
	/**
	 * Deletes an item from the repository.
	 * @param item The item to delete.
	 * @returns Promise that resolves once the request has completed.
	 */
	remove(item: T): Promise<void>;
	/**
	 * Saves new and/or updated items.
	 * @param items The item(s) to save or update.
	 * @return Promise with the saved objects.
	 */
	save(items: T | T[]): Promise<T[]>;
	/**
	 * Find all repository items matching the filter parameters.
	 *
	 * @param params Filter parameters. Use {@link .FilterInterface} to create them.
	 * @returns Promise with the entities that match the filter.
	 */
	filter(params: RestFilterInterface): Promise<T[]>;
}
/**
 * Filter builder, to be used with {@link RestRepositoryInterface.filter}
 */
export interface FilterInterface {
	/**
	 * Construct the filter
	 *
	 * @returns The filter
	 */
	build(): RestFilterInterface;
	/**
	 * Return only items that are inside the specified bounding box.
	 *
	 * @param xMin Lower X coordinate.
	 * @param yMin Lower Y coordinate.
	 * @param xMax Upper X coordinate.
	 * @param yMax Upper Y coordinate.
	 */
	boundingBox(xMin: number, yMin: number, xMax: number, yMax: number): this;
	/**
	 * Return the specified maximum number of items.
	 *
	 * @param limit Maximum number of items to return.
	 */
	limit(limit: number): this;
	/**
	 * Skip the specified number of items.
	 *
	 * @param offset Number of items to skip.
	 */
	offset(offset: number): this;
	/**
	 * Return only items that are inside the specified site model entity.
	 *
	 * Multiple entities can be provided, the item has to be contained in only one of them.
	 * Specify `undefined` to include items that are in no site model entity.
	 *
	 * This method can be called multiple times.
	 *
	 * @param entities List of site model entities.
	 */
	siteModel(entities: SiteModelEntityInterface[]): this;
	/**
	 * Sort results by the specific field name.
	 *
	 * @param {string} field Field name to sort by.
	 */
	sortBy(field: string): this;
	/**
	 * Sort results in the specific order (ascending or descending).
	 *
	 * @param {SortOrder} order Sort order.
	 */
	sortOrder(order: SortOrder): this;
	/**
	 * Regularly subsample the list of items returned.
	 *
	 * @deprecated use with items with non-sequential IDs might lead to inconsistent results
	 * @param step Step size, where 1 returns every item, 2 returns every other item, etc.
	 */
	step(step: number): this;
}
/**
 * Filter builder for [POI](../../../help/glossary.html#term-point-of-interest)s,
 * to be used with {@link RestRepositoryInterface.filter}
 */
export interface PoiFilterInterface extends FilterInterface {
	/**
	 * Return only items that are of the specified type(s)
	 *
	 * Multiple types can be provided, the item's type has to match one of them.
	 *
	 * @param poiTypes [POI](../../../help/glossary.html#term-point-of-interest) types to return
	 */
	poiType(poiTypes: PoiTypeInterface[]): this;
	/**
	 * Return only items that have a type that is part of the specified type group(s)
	 *
	 * Multiple type groups can be provided, the item's type has to be part of one of them.
	 *
	 * @param poiTypeGroups POI type groups to return
	 */
	poiTypeGroup(poiTypeGroups: PoiTypeGroupInterface[]): this;
	/**
	 * Return only items with an attribute value matching the specified values.
	 *
	 * If multiple attribute key value pairs are supplied, only points of interest that have
	 * attribute values matching ALL key value pairs in the dictionary are returned.
	 *
	 * @param attributes The attribute values
	 */
	attributes(attributes: Dictionary<string>): this;
}
/**
 * The PoiRepository retrieves POIs from the database through the REST API.
 *
 * A full list of POIs can be fetched by calling {@link findAll} and a specific
 * POI by calling {@link findOne}.
 */
export interface PoiRepositoryInterface extends RestRepositoryInterface<PoiInterface> {
	/**
	 * Generates a {@link PoiFilterInterface} object that is used for building data fetch queries.
	 */
	createFilterBuilder(): PoiFilterInterface;
}
/**
 * The PoiTypeRepository retreives PoiTypes from the database through the REST API.
 *
 * A full list of PoiTypes can be fetched by calling {@link findAll} and a specific
 * PoiType by calling {@link findOne}.
 */
export interface PoiTypeRepositoryInterface extends RestRepositoryInterface<PoiTypeInterface> {
}
/**
 * Represents a connection of a callback to a signal.
 */
export interface SignalConnection {
	/**
	 * Stop this connection from receiving further events permanently.
	 *
	 * @returns false if the connection has already been severed.
	 */
	disconnect(): boolean;
	/**
	 * If set to false it prevents the handler from receiving the signals events.
	 */
	enabled: boolean;
}
declare class Signal<THandler extends (...args: any[]) => any> {
	private readonly head;
	private hasNewLinks;
	private emitDepth;
	private connectionsCount;
	/**
	 * @returns The number of connections on this signal.
	 */
	getConnectionsCount(): number;
	/**
	 * @returns true if this signal has connections.
	 */
	hasConnections(): boolean;
	/**
	 * Subscribe to this signal.
	 *
	 * @param callback This callback will be run when emit() is called.
	 * @param order Handlers with a higher order value will be called later.
	 */
	connect(callback: THandler, order?: number): SignalConnection;
	private decrementConnectionCount;
	/**
	 * Unsubscribe from this signal with the original callback instance.
	 * While you can use this method, the SignalConnection returned by connect() will not be updated!
	 *
	 * @param callback The callback you passed to connect().
	 */
	disconnect(callback: THandler): boolean;
	/**
	 * Disconnect all handlers from this signal event.
	 */
	disconnectAll(): void;
	/**
	 * Publish this signal event (call all handlers).
	 */
	emit(...args: Parameters<THandler>): void;
	protected emitCollecting(collector: Collector<THandler>, args: Parameters<THandler>): void;
	private unsetNewLink;
}
declare abstract class Collector<THandler extends (...args: any[]) => any> {
	/**
	 * Publish the bound signal event (call all handlers) to start the collection process.
	 *
	 * @method
	 */
	readonly emit: (...args: Parameters<THandler>) => void;
	/**
	 * Create a new collector.
	 *
	 * @param signal The signal to emit.
	 */
	constructor(signal: Signal<THandler>);
	/**
	 * Process the results of a handler invocation.
	 *
	 * @param result true to continue processing handlers.
	 */
	abstract handleResult(result: ReturnType<THandler>): boolean;
}
export type ZoomHandler = 
/**
 * Signal handler for zoom events
 */
() => void;
export interface MapViewInterface extends AbstractViewInterface {
	/**
	 * Signal that is emitted after the zoom has changed
	 */
	onZoom: Signal<ZoomHandler>;
	/**
	 * Whether to hide POIs that would overlap others. True by default.
	 */
	hideOverlappingPois: boolean;
	/**
	 * Returns the LocationMarker layer
	 *
	 * @returns {SceneLayerInterface} LocationMarker layer if found, undefined otherwise
	 */
	getLocationMarkerLayer(): SceneLayerInterface;
	/**
	 * Returns the POI layer
	 *
	 * @returns {SceneLayerInterface} POI layer if found, undefined otherwise
	 */
	getPoiLayer(): SceneLayerInterface;
	/**
	 * Returns the Route layer
	 *
	 * @returns {SceneLayerInterface} Route layer if found, undefined otherwise
	 */
	getRouteLayer(): SceneLayerInterface;
}
export interface IvionInterface {
	/**
	 * Reinitialize NavVis IVION instance and re-fetch all data from database.
	 *
	 * @returns Promise that is resolved when the NavVis IVION instance has reinitialized. The promise
	 * will not be rejected.
	 */
	reinit(): Promise<void>;
	/**
	 * Similar to moveToPoi, uses numerical ID of [POI](../../../help/glossary.html#term-point-of-interest).
	 *
	 * @param poiId The [POI](../../../help/glossary.html#term-point-of-interest)'s ID.
	 * @param hideDetails By default NavVis IVION auto opens POI details panel, If `true` then that action is prevented.
	 * @param viewDir View orientation. If `undefined`, the default direction is used.
	 * @param fov Field of view as float. If `undefined`, the FOV is left unchanged.
	 *
	 * @returns Promise that is resolved when the moving transition is completely finished.
	 */
	moveToPoiId(poiId: number, hideDetails: boolean, viewDir: ViewOrientationInterface, fov: number): Promise<void>;
	/**
	 * Moves user to a location closest to the [POI](../../../help/glossary.html#term-point-of-interest) and sets the viewing direction such that the user is looking at
	 * the [POI](../../../help/glossary.html#term-point-of-interest).
	 *
	 * @param poi The [POI](../../../help/glossary.html#term-point-of-interest) object.
	 * @param hideDetails By default NavVis IVION auto opens [POI](../../../help/glossary.html#term-point-of-interest) details panel, If true then that action is prevented.
	 * @param viewDir View orientation. If `undefined`, the default direction is used.
	 * @param fov Field of view as float. If `undefined`, the FOV is left unchanged.
	 *
	 * @returns Promise that is resolved when the moving transition is completely finished.
	 */
	moveToPoi(poi: PoiInterface, hideDetails: boolean, viewDir: ViewOrientationInterface, fov: number): Promise<void>;
	/**
	 * Move to configured starting location.
	 *
	 * @returns Promise that is resolved when the moving transition is completely finished.
	 */
	moveToStartingLoc(): Promise<void>;
	/**
	 * Moves user to an image's location, uses numerical ID of the image object.
	 *
	 * @param imageId Image's ID. If not provided or `undefined`, defaults to first image.
	 * @param viewDir View orientation. If `undefined`, current view direction is left unchanged.
	 * @param fov Field of view as float. If `undefined`, the FOV is left unchanged.
	 *
	 * @returns Promise that is resolved when the moving transition is completely finished.
	 */
	moveToImageId(imageId: number, viewDir: ViewOrientationInterface, fov: number): Promise<void>;
	/**
	 * Moves user to an image's location.
	 *
	 * @param image Image object.
	 * @param viewDir View orientation. If `undefined`, current view direction is left unchanged.
	 * @param viewDistance Radius parameter. Image meshes are scaled to this radius before animation starts.
	 * @param fov Field of view as float. If `undefined`, the FOV is left unchanged.
	 *
	 * @note If `viewDistance` is not specified, a server-side raycast query for the center of the screen is performed
	 *       in order to find the scene depth (assuming the user is focusing on the screen center).
	 *
	 * @returns Promise that is resolved when the moving transition is completely finished.
	 */
	moveToImage(image: ImageInterface, viewDir?: ViewOrientationInterface, viewDistance?: number, fov?: number): Promise<void>;
	/**
	 * Move to specified geographic location by locating the closest image floor location
	 * and moving the view there.
	 * Images without geo-registration (i.e. where location is `null`) are ignored.
	 * If no image is found nearby but the location is still contained in a dataset, the view will
	 * be moved to the exact location and the point cloud will be activated.
	 *
	 * @param loc Geographic location in WGS-84 or local
	 * @param isLocal If false, coordinate is transformed from WGS-84 to local
	 * @param viewDir View orientation. If `undefined`, camera is oriented to view the location.
	 * @param fixedLat If is not `undefined` then this value will override the viewing direction's latitude value.
	 * @param fov Field of view as number. If `undefined`, the FOV is left unchanged.
	 * @param normal Normal vector of the destination. Used to determine if destination is floor/wall/ceiling.
	 * @param forceLoc Flag to force movement to specified location even if an image is found nearby.
	 * @param sameFloor If `true`, only images of the current floor are considered as destination.
	 *
	 * @note If viewDir is `undefined`, the viewing direction is determined automatically.
	 *
	 * @returns Promise that is resolved when the moving transition is completely finished.
	 */
	moveToGeoLocation(loc: Vector3, isLocal: boolean, viewDir: ViewOrientationInterface, fixedLat: number, fov: number, normal: Vector3, forceLoc: boolean, sameFloor?: boolean): Promise<void>;
	/**
	 * Moves user to a specified dataset. If image file ID is given, move is done to that image in dataset.
	 *
	 * @param datasetId Dataset's ID.
	 * @param imageFileId ID of image file. If not given or not found, first image from dataset is used.
	 * @param viewDir
	 *
	 * @returns Promise that is resolved when the moving transition is completely finished.
	 */
	moveToDataset(datasetId: number, imageFileId?: number, viewDir?: ViewOrientationInterface): Promise<void>;
	/**
	 * Moves user to the center of a specified site model entity.
	 *
	 * @param entity Entity to move to.
	 * @param showDetails Whether to open the details panel or not.
	 * @param viewDir View orientation. If ``undefined``, the direction is not changed.
	 *
	 * @returns Promise that is resolved when the moving transition is completely finished.
	 */
	moveToSiteModelEntity(entity: SiteModelEntityInterface, showDetails: boolean, viewDir?: ViewOrientationInterface): Promise<void>;
	/**
	 * Moves user to the center of a specified site model entity.
	 *
	 * @param entityId ID of the entity to move to.
	 * @param showDetails Whether to open the details panel or not.
	 * @param viewDir View orientation. If ``undefined``, the direction is not changed.
	 *
	 * @returns Promise that is resolved when the moving transition is completely finished.
	 */
	moveToSiteModelEntityId(entityId: number, showDetails: boolean, viewDir?: ViewOrientationInterface): Promise<void>;
	/**
	 * Return whether the view is currently being moved to another location,
	 * e.g., because `moveToImage()` had been called earlier.
	 *
	 * @returns Movement active.
	 */
	isMoving(): boolean;
	/**
	 * Get the main view.
	 *
	 * @returns Main view.
	 */
	getMainView(): MainViewInterface;
	/**
	 * Get the map view.
	 *
	 * @returns Map view.
	 */
	getMapView(): MapViewInterface;
	/**
	 * Moves the camera/user back to the center of the last visited image's sphere.
	 */
	resetView(): void;
	/**
	 * Set visibility for all or only given [POI](../../../help/glossary.html#term-point-of-interest) types.
	 *
	 * @param visible true to show and false to hide [POI](../../../help/glossary.html#term-point-of-interest) types. If parameter is not correct boolean type, function has no effect
	 * @param types Array with [POI](../../../help/glossary.html#term-point-of-interest) type IDs to set visibility. If not given, all [POI](../../../help/glossary.html#term-point-of-interest) types are set
	 */
	setPoiTypesVisibility(visible: boolean, types?: number[]): void;
	/**
	 * Get share URL containing information about current image, longitude and latitude.
	 *
	 * @returns Share URL.
	 */
	getShareUrl(): string;
	/**
	 * Set language (example: `en` for English).
	 *
	 * @param key Language key.
	 * Supported language keys are:
	 * * `cs`: Czech
	 * * `en`: English
	 * * `es`: Spanish
	 * * `de`: German
	 * * `ja`: Japanese
	 * * `zh`: Simplified Chinese
	 * * `zh_tw`: Traditional Chinese
	 */
	setLanguage(key: string): void;
	/**
	 * Get language (example: returns `en` for English).
	 *
	 * @returns Language key. See {@link setLanguage} for the list of supported languages.
	 */
	getLanguage(): string;
	/**
	 * Menu items organized in a tree structure with an array on the root level.
	 *
	 * Supported actions that can be performed on the retrieved items structure:
	 * - Adding new items in any place of the tree
	 * - Updating existing items
	 * - Deleting existing items
	 *
	 * @returns Menu items
	 */
	getMenuItems(): SidebarMenuItemInterface[];
	/**
	 * Checks whether the instance key includes the module for the frontend API.
	 *
	 * @returns Whether frontend API is included in the license
	 */
	isLicensed(): boolean;
	/**
	 * Gets the [POI](../../../help/glossary.html#term-point-of-interest) Repository object.
	 */
	getPoiRepository(): PoiRepositoryInterface;
	/**
	 * Gets the [POI](../../../help/glossary.html#term-point-of-interest) Type Repository object.
	 */
	getPoiTypeRepository(): PoiTypeRepositoryInterface;
}
/**
 * Software version of NavVis IVION according to the https://semver.org/ scheme.
 */
export interface VersionInfoInterface {
	/**
	 * The NavVis IVION major version number, corresponds to the first digit in version like 1.x.x
	 */
	major: number;
	/**
	 * The NavVis IVION minor version number, corresponds to the middle digit in version like x.2.x
	 */
	minor: number;
	/**
	 * The NavVis IVION revision number, corresponds to the last digit in version like x.x.3
	 */
	revision: number;
	/**
	 * Compare this version against the version specified by the provided parameters.
	 * Returns a negative number if this version is lower than the one specified by the provided
	 * parameters, a positive number if this version is higher than the one specified by the
	 * provided parameters, or 0 if they are equivalent.
	 *
	 * @param major The major version number to compare with
	 * @param minor The minor version number to compare with
	 * @param revision The revision number to compare with
	 */
	compareTo(major: number, minor: number, revision: number): number;
}
/**
 * The interface that holds information about the third party libraries used by NavVis IVION.
 */
export interface ThirdPartyLibrary {
	/**
	 * The name of the third party library.
	 */
	name: string;
	/**
	 * The website URL for the third party library.
	 */
	websiteUrl: string;
	/**
	 * The licenses under which the third party library is published
	 */
	licenses: LicenceInformation[];
	/**
	 * The description for the library.
	 */
	description: string;
}
export interface LicenceInformation {
	name: string;
	text: string;
}
/**
 * Use the About interface to access information related to the application, such as its version or
 * the list of third party applications it uses.
 */
export interface AboutServiceInterface {
	/**
	 * Retrieve the application version.
	 */
	getVersion(): Promise<VersionInfoInterface>;
	/**
	 * Retrieve a list of third party libraries used by the application, along with their respective
	 * licenses.
	 */
	getThirdPartyLibraries(): Promise<ThirdPartyLibrary[]>;
}
/**
 * Use the AboutApiInterface to access the object that encapsulates information related to the
 * application, such as its version or the list of third party applications it uses.
 */
export interface AboutApiInterface {
	/**
	 * Service that provides access to information related to the application.
	 */
	service: AboutServiceInterface;
}
/**
 * A coordinate reference system (e.g. WGS 84 or a Cartesian system)
 */
export interface ReferenceSystemInterface {
	/**
	 * Whether the coordinate reference system is geodetic (has a EPSG code or a Proj.4 definition)
	 */
	geodetic: boolean;
	/**
	 * Name of the coordinate reference system
	 */
	name: string;
	/**
	 * Description of the coordinate reference system
	 */
	description?: string;
	/**
	 * Proj.4 definition for a geodetic system that does not have an EPSG code
	 */
	proj4def?: string;
}
/**
 * A Dataset contains and groups the recoded data (like images, point clouds, or maps).
 */
export interface DatasetInterface extends RepositoryObjectInterface {
	/**
	 * Name representing the dataset.
	 */
	name: string;
	/**
	 * Short summary text describing the dataset.
	 */
	title: string;
	/**
	 * Visibility of the dataset's point cloud.
	 */
	pointCloudVisible: boolean;
	/**
	 * Dataset's coordinate reference system.
	 */
	crs: ReferenceSystemInterface;
	/**
	 * Site model entities in which the dataset is located.
	 */
	siteModelEntities: SiteModelEntityInterface[];
	/**
	 * Timestamp of when the dataset was recorded.
	 */
	acquisitionTime: Date;
}
export interface DatasetRepositoryInterface extends RestRepositoryInterface<DatasetInterface> {
}
/**
 * The Dataset API encapsulates objects that concern datasets.
 */
export interface DatasetApiInterface {
	/**
	 * Data repository for datasets with read and write capabilities.
	 * The {@link DatasetRepositoryInterface} provides [CRUD](https://en.wikipedia.org/wiki/Create,_read,_update_and_delete) endpoints.
	 */
	repository: DatasetRepositoryInterface;
}
/**
 * Filter builder for images, to be used with {@link RestRepositoryInterface.filter}
 */
export interface ImageFilterInterface extends FilterInterface {
	/**
	 * Return only items that have the hidden flag set to the specified value.
	 *
	 * @param hidden Hidden flag to filter for
	 */
	hidden(status: boolean): this;
	/**
	 * Return only images that are at least the given distance apart. This filter is 2D, i.e.,
	 * the Z coordinate is ignored.
	 *
	 * @param spacing Minimum distance between images [m].
	 */
	spacing(spacing: number): this;
}
export interface ImageRepositoryInterface extends RestRepositoryInterface<ImageInterface> {
	/**
	 * Generates a {@link ImageFilterInterface} object that is used for building data fetch queries.
	 */
	createFilterBuilder(): ImageFilterInterface;
}
export interface ImageServiceInterface {
	/**
	 * Finds the closest image for the given local position. Optionally with restriction to the given
	 * [site model](../../../help/glossary.html#term-site) entities (or none if the array contains `undefined`).
	 * Fails if no image is found.
	 *
	 * @param {Vector3|Vector2} location Local location around which to get the closest image.
	 * Note that 3D vector will sort by absolute distance, so if you want orthographic, pass 2D vector.
	 * @param {number} radius Radius limit [m].
	 * @param {SiteModelEntityInterface[]} smes The site model entities to restrict the search to.
	 * Pass an `undefined` item in the array to include images without a site model entity.
	 *
	 * @return {Promise<ImageInterface>} The {@link ImageInterface} if found, otherwise rejects.
	 */
	getClosestImage(location: Vector3 | Vector2, radius?: number, smes?: SiteModelEntityInterface[]): Promise<ImageInterface>;
	/**
	 * Find the closest non-hidden image to the target point. The target point is located in distance
	 * (dir * dist) in the direction of view.
	 *
	 * @param {ImageInterface} image The starting image from which to search.
	 * @param {ViewOrientationInterface} currViewingDir The current viewing direction.
	 * @param {number} dir The direction modifier: +1 for forward, -1 for backward.
	 * @param {number} distance How far away to move to approximately.
	 * @return {Promise<ImageInterface>} The nearest image in the direction at the distance, or reject
	 * if none found.
	 */
	getClosestImageInDir(image: ImageInterface, currViewingDir: ViewOrientationInterface, dir: number, distance: number): Promise<ImageInterface>;
	/**
	 * This method will look for the closest image on the same floor as the location given. If not
	 * within a floor the closest image without a {@link SiteModelEntityInterface} will be returned.
	 * @param {Vector3} location The local location for which to return the nearest image, on the
	 * same floor.
	 * @param {number} radius Optionally only within a radius [m].
	 * @return {Promise<ImageInterface>} The {@link ImageInterface} if found, otherwise rejects.
	 */
	getClosestImageOnFloor(location: Vector3, radius?: number): Promise<ImageInterface>;
}
/**
 * The Image API encapsulates object that concern (panoramic) images.
 */
export interface ImageApiInterface {
	/**
	 * Data repository for images with read and write capabilities.
	 * The {@link ImageRepositoryInterface} provides [CRUD](https://en.wikipedia.org/wiki/Create,_read,_update_and_delete) endpoints.
	 */
	repository: ImageRepositoryInterface;
	/**
	 * Service that provides additional functionality for operations related to images.
	 */
	service: ImageServiceInterface;
}
/**
 * Enum representing all the types of licensable features
 */
export declare enum LicenseFeatureType {
	ROUTING = "routing",
	JAVASCRIPT_API = "api",
	POSITIONING = "indoor_location_server",
	POI_AUDIT = "poi_audit",
	OIDC = "oidc"
}
export interface LicenseServiceInterface {
	/**
	 * Checks whether the given {@link LicenseFeatureType} is enabled in the license.
	 *
	 * @param {LicenseFeatureType} featureType Type of the feature to check
	 * @returns {boolean}
	 */
	isFeatureEnabled(featureType: LicenseFeatureType): boolean;
}
/**
 * The License API encapsulates objects that concern the license info.
 * Note: In order to check whether an API is licensed, use {@link ApiInterface.isLicensed}
 */
export interface LicenseApiInterface {
	/**
	 * Service that provides additional functionality for operations related to the license.
	 */
	service: LicenseServiceInterface;
}
/**
 * The PoiTypeGroupRepository retreives PoiTypeGroups from the database through the REST API.
 *
 * A full list of PoiTypeGroups can be fetched by calling {@link findAll} and a specific
 * PoiTypeGroup by calling {@link findOne}.
 */
export interface PoiTypeGroupRepositoryInterface extends RestRepositoryInterface<PoiTypeGroupInterface> {
}
/**
 * Enum describing where the POI was clicked by the user (3d view, search results UI, site model details panel)
 */
export declare enum PoiClickOrigin {
	VIEW = 0,
	SEARCH = 1,
	SITE_MODEL_DETAILS = 2
}
export type PoiOpenHandler = 
/**
 * Signal handler that is called when the POI details panel is opened.
 *
 * @param poi Opened POI
 */
(poi: PoiInterface) => void;
export type PoiCloseHandler = 
/**
 * Signal handler that is called when the POI details panel is closed.
 *
 * @param poi Closed POI
 */
(poi: PoiInterface) => void;
export type PoiHighlightHandler = 
/**
 * Signal handler that is called when POIs are highlighted in scene.
 *
 * @param pois Highlighted POIs.
 */
(pois: PoiInterface[]) => void;
export type PoiUnhighlightHandler = 
/**
 * Signal handler that is called when POIs are unhighlighted in the scene.
 *
 * @param pois Unhighlighted POIs.
 */
(pois: PoiInterface[]) => void;
export type PoiClickHandler = 
/**
 * Signal handler that is called when a user clicks the POI either in the scene or UI.
 * Return true in order to consume the event and prevent the default on POI click action.
 * Return false to let the default action proceed.
 *
 * @param poi Clicked POI
 * @param origin Identifier of component that emitted the click event
 */
(poi: PoiInterface, origin: PoiClickOrigin) => boolean;
export type PoiMouseOverHandler = 
/**
 * Signal handler that is called when a user enters the POI in scene with mouse.
 *
 * @param poi Entered POI
 */
(poi: PoiInterface) => void;
export type PoiMouseOutHandler = 
/**
 * Signal handler that is called when a user leaves the POI in scene with mouse.
 *
 * @param poi Left POI
 */
(poi: PoiInterface) => void;
export type PoiSaveHandler = 
/**
 * Signal handler that is called when a POI is saved.
 *
 * @param poi Saved POI
 * @param created True if a new POI is created, false if an existing one is updated
 */
(poi: PoiInterface, created: boolean) => void;
export type PoiDeleteHandler = 
/**
 * Signal handler that is called when a POI is deleted.
 *
 * @param poi Deleted POI
 */
(poi: PoiInterface) => void;
export interface PoiServiceInterface {
	/**
	 * Signal that is emitted when the [POI](../../../help/glossary.html#term-point-of-interest) details panel is opened.
	 */
	readonly onPoiOpen: Signal<PoiOpenHandler>;
	/**
	 * Signal that is emitted when the [POI](../../../help/glossary.html#term-point-of-interest) details panel closed.
	 */
	readonly onPoiClose: Signal<PoiCloseHandler>;
	/**
	 * Signal that is emitted when [POI](../../../help/glossary.html#term-point-of-interest)s are highlighted.
	 */
	readonly onPoisHighlight: Signal<PoiHighlightHandler>;
	/**
	 * Signal that is emitted when [POI](../../../help/glossary.html#term-point-of-interest)s are unhighlighted.
	 */
	readonly onPoisUnhighlight: Signal<PoiUnhighlightHandler>;
	/**
	 * Signal that is emitted when a user clicks the [POI](../../../help/glossary.html#term-point-of-interest) either in the scene or UI.
	 */
	readonly onPoiClick: Signal<PoiClickHandler>;
	/**
	 * Signal that is emitted when a user enters the [POI](../../../help/glossary.html#term-point-of-interest) with mouse in the scene.
	 */
	readonly onPoiMouseOver: Signal<PoiMouseOverHandler>;
	/**
	 * Signal that is emitted when a user leaves the [POI](../../../help/glossary.html#term-point-of-interest) with mouse in the scene.
	 */
	readonly onPoiMouseOut: Signal<PoiMouseOutHandler>;
	/**
	 * Signal that is emitted when a [POI](../../../help/glossary.html#term-point-of-interest) is saved in the current, local session.
	 */
	readonly onPoiSave: Signal<PoiSaveHandler>;
	/**
	 * Signal that is emitted when a [POI](../../../help/glossary.html#term-point-of-interest) is deleted in the current, local session.
	 */
	readonly onPoiDelete: Signal<PoiDeleteHandler>;
	/**
	 * An array of the [POI](../../../help/glossary.html#term-point-of-interest)s that have been highlighted in the scene.
	 */
	readonly highlightedPois: Set<PoiInterface>;
	/**
	 * [POI](../../../help/glossary.html#term-point-of-interest) with the currently opened POI details panel.
	 */
	readonly openedPoi: PoiInterface;
	/**
	 * Highlights given [POI](../../../help/glossary.html#term-point-of-interest)s in the scene.
	 * Emits {@link onPoisHighlight} signals.
	 *
	 * @param pois POIs to highlight
	 */
	highlightPois(pois: PoiInterface[]): void;
	/**
	 * Removes highlight from given [POI](../../../help/glossary.html#term-point-of-interest)s in the scene.
	 * Emits {@link onPoisUnhighlight} signals.
	 *
	 * @param pois POIs to unhighlight
	 */
	unhighlightPois(pois: PoiInterface[]): void;
	/**
	 * Opens the [POI](../../../help/glossary.html#term-point-of-interest) details panel. Closes the current {@link openedPoi}.
	 * Emits {@link onPoiOpen} signal.
	 *
	 * @param {PoiInterface} poi POI to highlight.
	 * @returns {boolean} false if the details panel is deactivated in the settings.
	 */
	openPoi(poi: PoiInterface): boolean;
	/**
	 * Closes the [POI](../../../help/glossary.html#term-point-of-interest) details panel if it is visible.
	 * Emits {@link onPoiClose} signal.
	 */
	closePoi(): void;
	/**
	 * Moves the view to the [POI](../../../help/glossary.html#term-point-of-interest).
	 *
	 * @param {PoiInterface} poi POI to move to. If not specified, the {@link PoiServiceInterface.openedPoi} is used.
	 * @returns {Promise<void>}
	 */
	goToPoi(poi?: PoiInterface): Promise<void>;
	/**
	 * Re-renders [POI](../../../help/glossary.html#term-point-of-interest)s in the scenes.
	 */
	refreshPois(): void;
}
/**
 * POI API object that encapsulates all classes and methods that are necessary for API users working
 * with everything related to POIs.
 */
export interface PoiApiInterface {
	readonly repository: PoiRepositoryInterface;
	readonly poiTypeRepository: PoiTypeRepositoryInterface;
	readonly poiTypeGroupRepository: PoiTypeGroupRepositoryInterface;
	readonly service: PoiServiceInterface;
}
/**
 * [Site model](../../../help/glossary.html#term-site) data repository.
 *
 * The site model repository object enables standard create, read, update, and
 * delete methods on site model entities. Additional helpful methods are provided
 * that enable more advanced retrieval of site model entities.
 */
export interface SiteModelRepositoryInterface extends RestRepositoryInterface<SiteModelEntityInterface> {
	/**
	 * Find [site model](../../../help/glossary.html#term-site) entities of a
	 * certain type within a given 2-dimensional radius [m] from a given point.
	 *
	 * @param type The {@link SiteModelType} to find.
	 * @param pos The starting, central point to search from.
	 * @param maxDist The maximum distance [m] from the central point.
	 */
	findByTypeAndDistance2D(type: SiteModelType, pos: Vector3, maxDist: number): Promise<SiteModelEntityInterface[]>;
	/**
	 * Find the closest [site model](../../../help/glossary.html#term-site) entity
	 * of a certain type within a given 2-dimensional radius [m] from a given point.
	 *
	 * @param type The {@link SiteModelType} to find.
	 * @param pos The starting, central point to search from.
	 * @param maxDist The maximum distance [m] from the central point.
	 */
	findClosestByTypeAndDistance2D(type: SiteModelType, pos: Vector3, maxDist: number): Promise<SiteModelEntityInterface>;
	/**
	 * Find [site model](../../../help/glossary.html#term-site) entities from a
	 * given local coordinate with optional site model type.
	 *
	 * @param localLocation Local point from which to find nearby site model entities.
	 * @param entityType Reduce search to include only the given site model type.
	 */
	findWithin(localLocation: Vector2 | Vector3, entityType?: SiteModelType): Promise<SiteModelEntityInterface[]>;
	/**
	 * Automatically generate a [site model](../../../help/glossary.html#term-site) based on all
	 * datasets in the instance. **Note** that this will overwrite any existing site model data.
	 */
	generate(): Promise<SiteModelEntityInterface[]>;
	/**
	 * Save [site model](../../../help/glossary.html#term-site) entities of type "BUILDING" or
	 * "FREE SPACE NAVIGATION AREA" to the database. **Note** that children SMEs of the given
	 * Building/Free-Space-Navigation-Area SME will be overwritten.
	 *
	 * @param objects Collection of {@link SiteModelEntityInterface}s to create or update.
	 */
	save(objects: SiteModelEntityInterface[]): Promise<SiteModelEntityInterface[]>;
	/**
	 * Update the attributes of the given [site model](../../../help/glossary.html#term-site)
	 * entities. **Please note** that this only persists data that are not geometric properties.
	 *
	 * @param objects Collection of {@link SiteModelEntityInterface}s to update.
	 */
	updateAttributes(objects: SiteModelEntityInterface[]): Promise<SiteModelEntityInterface[]>;
}
/**
 * The [site model](../../../help/glossary.html#term-site) API object encapsulates all classes and
 * methods that are necessary for API users working with the site model.
 */
export interface SiteModelApiInterface {
	/**
	 * Data repository object. This is used for creating, reading, updating, and deleting entities.
	 *
	 * @returns {SiteModelRepositoryInterface}
	 */
	repository: SiteModelRepositoryInterface;
	/**
	 * Types of constructs that the [site model](../../../help/glossary.html#term-site) polygon represents.
	 *
	 * @returns {SiteModelType}
	 */
	types: typeof SiteModelType;
}
/**
 * Enum representing the third party library dependencies and their package names
 */
export declare enum ThirdPartyLibraries {
	THREE = "three",
	TWEEN = "tweenjs",
	HAMMER = "hammerjs",
	ANGULAR = "angular",
	JQUERY = "jquery"
}
/**
 * Interface that holds version data of a third party library
 */
export interface ThirdPartyLibraryDetailsInterface {
	/**
	 * Human friendly name of the third party library
	 */
	readonly name: string;
	/**
	 * Package name of the third party library
	 */
	readonly library: string;
	/**
	 * Version of the third party library
	 */
	readonly version: string | undefined;
}
/**
 * Dictionary that holds version data about third party libraries
 */
export type ThirdPartyLibrariesInfo<T extends string, ThirdPartyLibraryDetailsInterface> = {
	[K in T]: ThirdPartyLibraryDetailsInterface;
};
/**
 * Service that exports dependencies like three.js, tween.js, AngularJS and jQuery
 */
export interface ThirdPartyLibraryInterface {
	/**
	 * Three.js (https://threejs.org/)
	 */
	readonly THREE: any;
	/**
	 * Tween.js (https://github.com/tweenjs/tween.js/)
	 */
	readonly TWEEN: typeof TWEEN;
	/**
	 * Hammer.JS (https://hammerjs.github.io/)
	 */
	readonly Hammer: any;
	/**
	 * AngularJS 1.x (https://angularjs.org/)
	 *
	 * @deprecated Do not rely on NavVis IVION's AnguarJS for your own application, it may be
	 * removed in a future version.
	 */
	readonly angular: any;
	/**
	 * jQuery (https://jquery.com/)
	 *
	 * @deprecated Do not rely on NavVis IVION's jQuery for your own application, it may be removed
	 * in a future version.
	 */
	readonly jQuery: any;
	/**
	 * Lists third party libraries and their versions
	 */
	readonly info: ThirdPartyLibrariesInfo<ThirdPartyLibraries, ThirdPartyLibraryDetailsInterface>;
}
/**
 * Transform coordinates and quaternions from one coordinate reference system into another one
 */
export interface TransformInterface {
	/**
	 * Source coordinate reference system
	 */
	source: ReferenceSystemInterface;
	/**
	 * Target coordinate reference system
	 */
	target: ReferenceSystemInterface;
	/**
	 * Transform a two-dimensional vector from the source to the target reference system.
	 *
	 * This method operates in-place, i.e., the vector is modified.
	 *
	 * @param vector Vector to transform
	 * @returns Transformed vector (same object as the argument)
	 */
	transform(vector: Vector2): Vector2;
	/**
	 * Transform a three-dimensional vector from the source to the target reference system.
	 *
	 * This method operates in-place, i.e., the vector is modified.
	 *
	 * @param vector Vector to transform
	 * @returns Transformed vector (same object as the argument)
	 */
	transform(vector: Vector3): Vector3;
	/**
	 * Transform a quaternion from the source to the target reference system.
	 *
	 * @param quaternion Quaternion to transform
	 * @param coordinate A coordinate in the source system that is close to the working area. Its
	 *   values will be modified in-place. Required if a geodetic transform is part of the
	 *   transform chain, in order to account for grid convergence. Ignored otherwise.
	 * @returns Transformed quaternion (same object as the argument)
	 */
	transformQuaternion(quaternion: Quaternion, location?: Vector2 | Vector3): Quaternion;
	/**
	 * Compute and return the inverse transform, i.e., the one that transforms from the
	 * target to the source reference system.
	 *
	 * @returns {TransformInterface} Inverse transform
	 */
	getInverse(): TransformInterface;
}
/**
 * Provide access to coordinate reference systems and to transforms between them.
 *
 * For convenience, this service provides a transform from WGS 84 to local Cartesian coordinates,
 * as well as the inverse transform. The local coordinate system will be relocated occasionally.
 * Subscribe to the related signals to get notified when that occurs and recompute all local
 * coordinates.
 */
export interface TransformServiceInterface {
	/**
	 * Get a coordinate reference system by name (e.g. "EPSG:4326" or "NAVVIS:LOCAL").
	 *
	 * Throws a {@link .ReferenceSystemNotFoundException} if the reference system cannot be found.
	 *
	 * @param {string} name Reference system name (AUTHORITY:ID)
	 * @returns {ReferenceSystemInterface}
	 */
	getReferenceSystem(name: string): ReferenceSystemInterface;
	/**
	 * Construct and return a transform from the source to the target reference system.
	 *
	 * Throws a {@link .TransformNotFoundException} if no transform between the systems exist.
	 *
	 * @param {ReferenceSystemInterface} source Source CRS
	 * @param {ReferenceSystemInterface} target Target CRS
	 * @returns {TransformInterface} Transform from source to target
	 */
	getTransform(source: ReferenceSystemInterface, target: ReferenceSystemInterface): TransformInterface;
	/**
	 * Download the Proj.4 definition for the provided EPSG coordinate reference system and
	 * add it to Proj4js' definitions.
	 *
	 * @param epsgName Name of the system, e.g. "EPSG:31468".
	 *
	 * @return Promise that resolves when the download has completed.
	 */
	downloadProj4Definition(epsgName: string): Promise<void>;
	/**
	 * List of registered reference systems
	 */
	readonly referenceSystems: ReferenceSystemInterface[];
	/**
	 * Transform from WGS 84 to the local working coordinate system
	 */
	readonly globalToLocal: TransformInterface;
	/**
	 * Transform from local working coordinate system to WGS 84
	 */
	readonly localToGlobal: TransformInterface;
	/**
	 * WGS 84 coordinate reference system (EPSG:4326)
	 */
	readonly crsGlobal: ReferenceSystemInterface;
	/**
	 * Local working coordinate reference system (NAVVIS:LOCAL)
	 */
	readonly crsLocal: ReferenceSystemInterface;
	/**
	 * Promise that resolves when the local reference system has been set
	 */
	readonly localReferenceSystemReady: Promise<void>;
	/**
	 * Signal that is emitted before the local reference system is changed
	 */
	readonly onBeforeLocalReferenceSystemChange: Signal<() => void>;
	/**
	 * Signal that is emitted after the local reference system has been changed
	 */
	readonly onAfterLocalReferenceSystemChange: Signal<() => void>;
}
export interface TransformApiInterface {
	/**
	 * Service that provides functionality to retrieve coordinate reference systems and transforms
	 * between them.
	 */
	service: TransformServiceInterface;
}
export type FloorChangeHandler = 
/**
 * Signal handler that is called when the current floor is changed.
 *
 * @param event Object with the list of current floor entities
 */
(event: FloorChangeEventInterface) => void;
/**
 * Event information about a floor change.
 *
 * This may be caused by a "real" floor change (e.g. ground floor to 1st floor) or when
 * the list of current floors is changed (e.g. a floor in another building comes into view).
 */
export interface FloorChangeEventInterface {
	/**
	 * List of current floors
	 */
	readonly currentFloors: SiteModelEntityInterface[];
}
export type FloorUpdateHandler = 
/**
 * Signal handler that is called when the list of available floors is changed.
 *
 * @param event Object with the list of available and the list of current floor entities
 */
(event: FloorUpdateEventInterface) => void;
/**
 * Event information about available floors.
 *
 * When panning the map view or changing the location, the list of available floors is updated.
 */
export interface FloorUpdateEventInterface {
	/**
	 * List of available floors
	 */
	readonly floors: SiteModelEntityInterface[];
	/**
	 * List of current floors
	 */
	readonly currentFloors: SiteModelEntityInterface[];
}
/**
 * The floor changer service reports available and current floors and provides methods to change
 * the current floor.
 */
export interface FloorChangerServiceInterface {
	/**
	 * Currently active floor entitites
	 */
	readonly currentFloors: SiteModelEntityInterface[];
	/**
	 * Signal that is emitted when the current floor is changed
	 */
	readonly onFloorChange: Signal<FloorChangeHandler>;
	/**
	 * Signal that is emitted when the list of available floors is changed
	 */
	readonly onFloorUpdate: Signal<FloorUpdateHandler>;
	/**
	 * Change the floor to the specified site model entity or one of its parent entities
	 *
	 * All floors with the same name are added to the list of current floors.
	 * The call may result in an onFloorChange event.
	 *
	 * @param {SiteModelEntity} entity A site model entity that is a floor or has a floor in its
	 *  ancestor chain
	 * @param {boolean} mayChangeLocation Indicates if floor change should cause a location change
	 *  (defaults to true for the panorama view being the main one, false for the main map view)
	 * @return {Promise<void>} Promise which resolves if a floorChanged event was triggered,
	 *  otherwise rejects.
	 */
	changeFloorByEntity(entity: SiteModelEntityInterface, mayChangeLocation?: boolean): Promise<void>;
	/**
	 * Change the current floor by a provided floor name
	 *
	 * All floors with the same name are added to the list of current floors.
	 * The call may result in an onFloorChange event.
	 *
	 * @param {string} floorName Name of floor to change to
	 * @param {boolean} mayChangeLocation Indicates if floor change should cause a location change
	 *  (defaults to true for the panorama view being the main one, false for the main map view)
	 * @return {Promise<void>} Promise which resolves if a floorChanged event was triggered,
	 *  otherwise rejects.
	 */
	changeFloorByName(floorName: string, mayChangeLocation?: boolean): Promise<void>;
}
export declare enum ViewType {
	MAP = "map",
	PANORAMA = "panorama"
}
/**
 * Service that provides functionality that extends beyond a single view
 */
export interface ViewServiceInterface {
	/**
	 * Signal that is emitted when a transition to a new location is started
	 */
	readonly onTransitionStart: Signal<TransitionStartHandler>;
	/**
	 * Signal that is emitted when a transition has completed
	 */
	readonly onTransitionEnd: Signal<TransitionEndHandler>;
	/**
	 * Whether to show the secondary view window or not.
	 */
	showSecondaryView: boolean;
	/**
	 * Whether to show the button that swaps the primary and secondary view window.
	 */
	viewSwapAllowed: boolean;
	/**
	 * Whether to automatically show point clouds when no panorama is available. True by default.
	 */
	allowPointCloudActivation: boolean;
	/**
	 * Get the {@link ViewType} that is currently in the primary view window.
	 * @returns {ViewType}
	 */
	getPrimaryView(): ViewType;
	/**
	 * Set the {@link ViewType} to be shown in the primary view window.
	 * @param {ViewType} view
	 */
	setPrimaryView(view: ViewType): void;
	/**
	 * Swaps the content displayed in the primary and the secondary view window.
	 */
	swapViews(): void;
	/**
	 * Update the HTML UI by triggering an Angular digest cycle.
	 *
	 * Usually the change detection is run automatically. In some rare cases, e.g. when changing the
	 * application state in a render callback, it is not run automatically and this method has to be
	 * called in order to update the UI.
	 */
	updateUi(): void;
}
export interface LayersServiceInterface {
	/**
	 * Activates the 2D layer with the provided ID. This will deactivate any other, previously active layer.
	 * @param layer a 2D layer ID. One of {@link LayerPanelItemEnum}.
	 */
	activate2DLayer(layer: string): void;
	/**
	 * Returns all 2D layer IDs as listed in {@link LayerPanelItemEnum}.
	 */
	get2DLayers(): string[];
}
/**
 * The View API provides access to the 3D views and to related signals.
 */
export interface ViewApiInterface {
	/**
	 * The main view displays panoramas, point clouds, POIs, location markers using a perspective
	 * camera.
	 */
	readonly mainView: MainViewInterface;
	/**
	 * The map view displays maps, POIs, location markers using an orthographic camera.
	 */
	readonly mapView: MapViewInterface;
	/**
	 * The view service provides functionality that extends beyond a single view
	 */
	readonly service: ViewServiceInterface;
	/**
	 * The floor changer service reports available and current floors and provides methods to change
	 * the current floor.
	 */
	readonly floorChangerService: FloorChangerServiceInterface;
	/**
	 * The layers service is used to list and activate 2D layers.
	 */
	readonly layersService: LayersServiceInterface;
}
export interface SidebarMenuServiceInterface {
	/**
	 * Menu items organized in a tree structure with an array on the root level.
	 *
	 * Supported actions that can be performed on the retrieved items structure:
	 * - Adding new items in any place of the tree
	 * - Updating existing items
	 * - Deleting existing items
	 *
	 * @returns {SidebarMenuItemInterface[]}
	 */
	items: SidebarMenuItemInterface[];
	/**
	 * Slides the Sidebar Menu user interface into view.
	 */
	openMenu(): void;
	/**
	 * Slides the Sidebar Menu user interface out of view.
	 */
	closeMenu(): void;
	/**
	 * Opens the {@link SidebarMenuItemInterface}.
	 *
	 * Note: only works for items that are visible in the menu.
	 *
	 * @param {SidebarMenuItemInterface} item
	 * @returns Promise that resolves when navigation has completed and rejects if user has
	 *   canceled the action (e.g. to keep unsaved changes in the current view).
	 */
	goToItem(item: SidebarMenuItemInterface): Promise<void>;
	/**
	 * Closes any open {@link SidebarMenuItemInterface} and displays the top-level
	 * menu items list.
	 */
	goToRoot(): void;
	/**
	 * Get the currently selected {@link SidebarMenuItemInterface}.
	 */
	getActiveItem(): SidebarMenuItemInterface;
}
/**
 * Available UI Languages.
 */
export declare enum UiLanguage {
	ENGLISH = "en",
	GERMAN = "de",
	CHINESE_TRADITIONAL = "zh_tw",
	CHINESE = "zh",
	JAPANESE = "ja",
	CZECH = "cs",
	FRENCH = "fr",
	SPANISH = "es"
}
/**
 * Enum to store decimal separators.
 */
export declare enum DecimalSeparators {
	COMMA = ",",
	POINT = "."
}
/**
 * Interface to store the names and number format with a language key.
 */
export interface Language {
	key: string;
	name: string;
	nativeName: string;
	numberFormat?: string;
	decimalSeparator?: DecimalSeparators;
}
/**
 * Available Data Languages.
 *
 * For languages with multiple names, every name for a particular language is treated as a separate
 * enum.
 */
export declare enum DataLanguage {
	ABKHAZ = "ab",
	AFAR = "aa",
	AFRIKAANS = "af",
	AKAN = "ak",
	ALBANIAN = "sq",
	AMHARIC = "am",
	ARABIC = "ar",
	ARAGONESE = "an",
	ARMENIAN = "hy",
	ASSAMESE = "as",
	AVARIC = "av",
	AVESTAN = "ae",
	AYMARA = "ay",
	AZERBAIJANI = "az",
	BAMBARA = "bm",
	BASHKIR = "ba",
	BASQUE = "eu",
	BELARUSIAN = "be",
	BENGALI = "bn",
	BIHARI = "bh",
	BISLAMA = "bi",
	BOSNIAN = "bs",
	BRETON = "br",
	BULGARIAN = "bg",
	BURMESE = "my",
	CATALAN = "ca",
	VALENCIAN = "ca",
	CHAMORRO = "ch",
	CHECHEN = "ce",
	CHICHEWA = "ny",
	CHEWA = "ny",
	NYANJA = "ny",
	CHINESE = "zh",
	CHINESE_TRADITIONAL = "zh_tw",
	CHUVASH = "cv",
	CORNISH = "kw",
	CORSICAN = "co",
	CREE = "cr",
	CROATIAN = "hr",
	CZECH = "cs",
	DANISH = "da",
	DIVEHI = "dv",
	DHIVEHI = "dv",
	MALDIVIAN = "dv",
	DUTCH = "nl",
	ENGLISH = "en",
	ESPERANTO = "eo",
	ESTONIAN = "et",
	EWE = "ee",
	FAROESE = "fo",
	FIJIAN = "fj",
	FINNISH = "fi",
	FRENCH = "fr",
	FULA = "ff",
	FULAH = "ff",
	PULAAR = "ff",
	PULAR = "ff",
	GALICIAN = "gl",
	GEORGIAN = "ka",
	GERMAN = "de",
	GREEK_MODERN = "el",
	GUARANÍ = "gn",
	GUJARATI = "gu",
	HAITIAN = "ht",
	HAITIAN_CREOLE = "ht",
	HAUSA = "ha",
	HEBREW_MODERN = "he",
	HERERO = "hz",
	HINDI = "hi",
	HIRI_MOTU = "ho",
	HUNGARIAN = "hu",
	INTERLINGUA = "ia",
	INDONESIAN = "id",
	INTERLINGUE = "ie",
	IRISH = "ga",
	IGBO = "ig",
	INUPIAQ = "ik",
	IDO = "io",
	ICELANDIC = "is",
	ITALIAN = "it",
	INUKTITUT = "iu",
	JAPANESE = "ja",
	JAVANESE = "jv",
	KALAALLISUT = "kl",
	GREENLANDIC = "kl",
	KANNADA = "kn",
	KANURI = "kr",
	KASHMIRI = "ks",
	KAZAKH = "kk",
	KHMER = "km",
	KIKUYU = "ki",
	GIKUYU = "ki",
	KINYARWANDA = "rw",
	KIRGHIZ = "ky",
	KYRGYZ = "ky",
	KOMI = "kv",
	KONGO = "kg",
	KOREAN = "ko",
	KURDISH = "ku",
	KWANYAMA = "kj",
	KUANYAMA = "kj",
	LATIN = "la",
	LUXEMBOURGISH = "lb",
	LETZEBURGESCH = "lb",
	LUGANDA = "lg",
	LIMBURGISH = "li",
	LIMBURGAN = "li",
	LIMBURGER = "li",
	LINGALA = "ln",
	LAO = "lo",
	LITHUANIAN = "lt",
	LUBA_KATANGA = "lu",
	LATVIAN = "lv",
	MANX = "gv",
	MACEDONIAN = "mk",
	MALAGASY = "mg",
	MALAY = "ms",
	MALAYALAM = "ml",
	MALTESE = "mt",
	MAORI = "mi",
	MARATHI = "mr",
	MARSHALLESE = "mh",
	MONGOLIAN = "mn",
	NAURU = "na",
	NAVAJO = "nv",
	NAVAHO = "nv",
	NORWEGIAN_BOKMAL = "nb",
	NDEBELE_NORTH = "nd",
	NEPALI = "ne",
	NDONGA = "ng",
	NORWEGIAN_NYNORSK = "nn",
	NORWEGIAN = "no",
	NUOSU = "ii",
	NDEBELE_SOUTH = "nr",
	OCCITAN = "oc",
	OJIBWE = "oj",
	OJIBWA = "oj",
	SLAVONIC_OLD_CHURCH = "cu",
	OROMO = "om",
	ORIYA = "or",
	OSSETIAN = "os",
	OSSETIC = "os",
	PANJABI = "pa",
	PUNJABI = "pa",
	PALI = "pi",
	PERSIAN = "fa",
	POLISH = "pl",
	PASHTO = "ps",
	PUSHTO = "ps",
	PORTUGUESE = "pt",
	QUECHUA = "qu",
	ROMANSH = "rm",
	KIRUNDI = "rn",
	ROMANIAN = "ro",
	MOLDAVIAN = "ro",
	MOLDOVAN = "ro",
	RUSSIAN = "ru",
	SANSKRIT = "sa",
	SARDINIAN = "sc",
	SINDHI = "sd",
	SAMI_NORTHERN = "se",
	SAMOAN = "sm",
	SANGO = "sg",
	SERBIAN = "sr",
	SCOTTISH_GAELIC = "gd",
	GAELIC = "gd",
	SHONA = "sn",
	SINHALA = "si",
	SINHALESE = "si",
	SLOVAK = "sk",
	SLOVENE = "sl",
	SOMALI = "so",
	SOTHO_SOUTHERN = "st",
	SPANISH = "es",
	CASTILIAN = "es",
	SUNDANESE = "su",
	SWAHILI = "sw",
	SWATI = "ss",
	SWEDISH = "sv",
	TAMIL = "ta",
	TELUGU = "te",
	TAJIK = "tg",
	THAI = "th",
	TIGRINYA = "ti",
	TIBETAN_STANDARD = "bo",
	TIBETAN_CENTRAL = "bo",
	TURKMEN = "tk",
	TAGALOG = "tl",
	TSWANA = "tn",
	TONGA = "to",
	TURKISH = "tr",
	TSONGA = "ts",
	TATAR = "tt",
	TWI = "tw",
	TAHITIAN = "ty",
	UIGHUR = "ug",
	UYGHUR = "ug",
	UKRAINIAN = "uk",
	URDU = "ur",
	UZBEK = "uz",
	VENDA = "ve",
	VIETNAMESE = "vi",
	VOLAPUEK = "vo",
	WALLOON = "wa",
	WELSH = "cy",
	WOLOF = "wo",
	FRISIAN_WESTERN = "fy",
	XHOSA = "xh",
	YIDDISH = "yi",
	YORUBA = "yo",
	ZHUANG = "za",
	CHUANG = "za"
}
export type LanguageChangeHandler = 
/**
 *  Signal handler that is called when the user interface language is changed.
 *
 * @param language The new user interface language.
 */
(language: Language) => void;
export interface LanguageServiceInterface {
	/**
	 * Signal that is emitted when the user interface language has been switched.
	 */
	readonly onLanguageChange: Signal<LanguageChangeHandler>;
	/**
	 * Switch the current language.
	 *
	 * *Note*: This changes both the user interface language (used for the default interface) and the data language (used for user-provided names and descriptions).
	 * In case the language defined by the language key is not supported, the data language is updated, but not the user interface language.
	 *
	 * If you only want to change the user interface language use the {@link setUiLanguage} method.
	 * Or, if you only want to change the data language use the {@link setDataLanguage} method.
	 *
	 * @param {string} key the two digit ISO-639-1 language key of the language you want to switch to.
	 * @return {Promise<void>} Promise which is resolved in case the switch was successful, rejected in case the language isn't supported by the user interface.
	 */
	setLanguage(key: string): Promise<void>;
	/**
	 * Change the user interface language to the language provided.
	 *
	 * @param {UiLanguage} language An enum with the language to switch to.
	 * @return {Promise<void>} Promise which is resolved in case the switch was successful, rejected in case the language wasn't supported by the user interface.
	 */
	setUiLanguage(language: UiLanguage): Promise<void>;
	/**
	 * Change the data language to the language provided.
	 *
	 * @param {DataLanguage} language An enum with the language to switch to.
	 */
	setDataLanguage(language: DataLanguage): void;
	/**
	 * Returns the current user interface language.
	 *
	 * @return {Language} The language currently being used as the user interface language.
	 */
	getCurrentUiLanguage(): Language;
	/**
	 * Returns the current data language.
	 *
	 * @return {Language} The language currently being used as the data language.
	 */
	getCurrentDataLanguage(): Language;
}
/**
 * The UI API provides services that enable control over the user interface elements, such as
 * customizing the {@link SidebarMenuItemInterface}.
 */
export interface UiApiInterface {
	/**
	 * The Sidebar Menu API enables control of and extension to the Sidebar Menu.
	 */
	sidebarMenuService: SidebarMenuServiceInterface;
	/**
	 * The Language API enables control of the user interface language and the data language.
	 */
	languageService: LanguageServiceInterface;
}
/**
 * The Social/Share API provides deep link URLs of a user's view, which can be shared.
 */
export interface ShareApiInterface {
	/**
	 * Generates the URL used for sharing. The URL is different depending on the current view.
	 *
	 * For the panorama view, the URL contains:
	 * - image
	 * - longitude and latitude of the current location
	 * - camera's field of view
	 *
	 * For the point cloud view, the URL contains:
	 * - parameter to turn on the point cloud view
	 * - longitude and latitude of the current location
	 * - longitude, latitude and height of the camera
	 * - camera's field of view
	 *
	 * For an empty instance, returns the instance base URL.
	 *
	 * @returns {string} The generated share URL.
	 */
	generateShareUrl(): string;
}
/**
 * Single route point. Contains associated metadata such as an attached instruction or associated site model entities.
 */
export interface RouteElementEntityInterface {
	/**
	 * Coordinate of the route element.
	 */
	location: Vector3;
	/**
	 * Distance between this element and the start of the route [m].
	 */
	distance: number;
	/**
	 * The {@link SiteModelEntityInterface} of type floor within which the route element is.
	 * `undefined` if the route element is not in a floor.
	 */
	floor: SiteModelEntityInterface;
	/**
	 * The most specific {@link SiteModelEntityInterface} of any type within which the route element lies.
	 * `undefined` if the route element is outside of the site model.
	 */
	siteModelEntity: SiteModelEntityInterface;
}
/**
 * Enum representing all possible instruction types that can be present in a route.
 */
export declare enum InstructionType {
	ENTER_BUILDING = "walk_inside",
	EXIT_BUILDING = "walk_outside",
	ENTER_ELEVATOR_UP = "enter_elevator_up",
	ENTER_ELEVATOR_DOWN = "enter_elevator_down",
	EXIT_ELEVATOR = "exit_elevator",
	ENTER_STAIRS_UP = "enter_stairs_up",
	ENTER_STAIRS_DOWN = "enter_stairs_down",
	EXIT_STAIRS = "exit_stairs",
	CHANGE_FLOOR_UP = "change_floor_up",
	CHANGE_FLOOR_DOWN = "change_floor_down",
	START = "start",
	END = "end",
	EDGE = "edge",
	SOURCE_PROJECTION = "source_projection_to_navgraph",
	DESTINATION_PROJECTION = "destination_projection_to_navgraph"
}
/**
 * Use the InstructionApiInterface to access methods which allow you to move to instruction and to
 * get the position (in site coordinates) and floor of the instruction.
 */
export interface InstructionApiInterface {
	/**
	 * Move the camera to the instruction.
	 * @returns {Promise<void>}
	 */
	moveToInstruction(): Promise<void>;
	/**
	 * Return the position (site coordinate) of the instruction.
	 */
	readonly position: Vector3;
	/**
	 * Return the floor of the instruction.
	 */
	readonly floor: SiteModelEntityInterface;
	/**
	 * Return the text of the instruction.
	 */
	readonly text: string;
	/**
	 * The type of the instruction.
	 */
	readonly type: InstructionType;
}
/**
 * The route data which contains all the necessary information about the route between two points.
 */
export interface RouteDataInterface {
	/**
	 * Calculated route path.
	 */
	elements: RouteElementEntityInterface[];
	/**
	 * The route length in meters.
	 *
	 * If routing to/from a point which is not on the ground, the projection on the ground of this
	 * point will be used to calculate the total length.
	 * Returns the distance from the ground projected start until the ground projected end [m].
	 */
	routeLength: number;
	/**
	 * Instructions for navigating through a route.
	 */
	instructions: InstructionApiInterface[];
	/**
	 * The message stating why finding a route failed. If finding a route was successful this will be empty.
	 */
	message: string;
	/**
	 * Flag which states whether the path is available or not.
	 */
	readonly available: boolean;
}
export type RouteChangeHandler = 
/**
 *  Signal handler that is called when there is a change in the route.
 *
 * @param route The data about the route.
 */
(route: RouteDataInterface) => void;
export type RouteInstructionMouseOverHandler = 
/**
 *  Signal handler that is called when the mouse is moved over a route instruction.
 *
 * @param instruction The route instruction over which the mouse is hovered.
 */
(instruction: InstructionApiInterface) => void;
export type RouteInstructionMouseOutHandler = 
/**
 *  Signal handler that is called when the mouse has moved out of a route instruction.
 *
 * @param instruction The route instruction that the mouse was moved out of.
 */
(instruction: InstructionApiInterface) => void;
export type RouteInstructionMouseClickHandler = 
/**
 *  Signal handler that is called when the user clicks on a route instruction.
 *
 * @param instruction The instruction where there was a mouse click.
 */
(instruction: InstructionApiInterface) => void;
/**
 * Route API object that encapsulates all classes and methods that contain all classes and
 * methods needed to work with routing.
 */
export interface RouteApiInterface {
	/**
	 * Find a route between the source and the destination. This will also open the user interface elements associated with the route.
	 * @param source The starting point of the route. If a Vector3 location is specified, it should be in site coordinates.
	 * @param destination The ending point of the route. If a Vector3 location is specified, it should be in site coordinates.
	 * @param moveToStart A boolean specifying whether to move to start or not. If not provided this parameter will default to true.
	 *
	 * @returns A promise which returns the route. In case there is no route found between the source and destination, the promise will be rejected with the specific reason for the rejection.
	 */
	route(source: Vector3 | PoiInterface, destination: Vector3 | PoiInterface, moveToStart?: boolean): Promise<RouteDataInterface>;
	/**
	 * Find a route between the source and the destination. Note: This method will only return the route and will not update any views.
	 * @param source A location in site coordinates.
	 * @param destination A location in site coordinates.
	 *
	 * @returns A promise which returns the route. In case there is no route found between the source and destination, the promise will be rejected with the specific reason for the rejection.
	 */
	getRoute(source: Vector3, destination: Vector3): Promise<RouteDataInterface>;
	/**
	 * Signal that is emitted when there is a change in the route.
	 */
	onRouteChanged: Signal<RouteChangeHandler>;
	/**
	 * Clear the current route and resets all associated user interface elements.
	 */
	clear(): void;
	/**
	 * Signal that is emitted when the mouse is moved over a route instruction.
	 */
	onRouteInstructionMouseOver: Signal<RouteInstructionMouseOverHandler>;
	/**
	 * Signal that is emitted when the mouse has moved out of a route instruction.
	 */
	onRouteInstructionMouseOut: Signal<RouteInstructionMouseOutHandler>;
	/**
	 * Signal that is emitted when the user clicks on a route instruction.
	 */
	onRouteInstructionClick: Signal<RouteInstructionMouseClickHandler>;
}
export interface SiteInterface extends RepositoryObjectInterface {
	/**
	 * The name of the site.
	 */
	name: string;
	/**
	 * ID of the draft site created from this site.
	 */
	draftId: number;
	/**
	 * ID of the published site from which this draft site is created.
	 */
	parentId: number;
}
export interface UserEntityInterface {
	/**
	 * Login name of the user.
	 */
	readonly username: string;
	/**
	 * Optional first name of the user.
	 */
	readonly firstName: string;
	/**
	 * Optional last name of the user
	 */
	readonly lastName: string;
	/**
	 * Optional email address of the user.
	 */
	readonly email: string;
	/**
	 * ID of the user.
	 */
	readonly id: number;
	/**
	 * Checks if the user is a global administrator.
	 */
	isAdmin(): boolean;
	/**
	 * Checks if the user is a site adminstrator on the provided site.
	 */
	isSiteAdmin(site: SiteInterface): boolean;
	/**
	 * Checks if the user is a guest, i.e. not logged in.
	 */
	isGuest(): boolean;
}
export type AuthenticationChangedHandler = 
/**
 *  Signal handler that is called after a user logged in or out.
 *
 * @param user User after the authentication changed. Will be a "guest"
 * user after logging out.
 * @param isDataAccessible Whether data is accessible or not. Will be true, if a user
 * just logged in. Otherwise data is only accessible if private mode is not enabled.
 */
(user: UserEntityInterface, isDataAccessible: boolean) => void;
/**
 * The Authentication API provides methods to log in or out, information about the current user, and
 * a signal for when the logged-in user changes.
 */
export interface AuthApiInterface {
	/**
	 * Signal that is emitted after a user logged in or out.
	 * After logging out, the user will be a "guest" user.
	 */
	readonly onAuthenticationChanged: Signal<AuthenticationChangedHandler>;
	/**
	 * Information about the currently logged in user. Will be a "guest" user if not logged in.
	 */
	readonly currentUser: UserEntityInterface;
	/**
	 * Logs in a user with the provided credentials.
	 *
	 * Note that this will only work with local NavVis IVION accounts, not with OAuth or
	 * pre-authentication.
	 *
	 * @param username Name of the user.
	 * @param password Password of the user.
	 * @param awaitDataLoad Optional flag that determines whether the returned promise should wait
	 * for the full initialization of NavVis IVION. Needs to be set true if the login promise is
	 * chained with some API functions. Defaults to false.
	 *
	 * @returns A promise that is resolved after successful login and rejected if e.g. the provided
	 * credentials are invalid.
	 */
	login(username: string, password: string, awaitDataLoad?: boolean): Promise<UserEntityInterface>;
	/**
	 * Logs out the currently logged in user.
	 *
	 * @returns A promise that is resolved after the logout.
	 */
	logout(): Promise<void>;
	/**
	 * Logs in a user with the provided JWT, either for local NavVis IVION accounts or e.g. for
	 * OAuth Resource Server if the instance is set up to use one.
	 *
	 * Note that it also removes logout functionality from the UI and that NavVis IVION will not
	 * automatically refresh the token when it is about to expire. Use {@link updateToken} to
	 * apply an updated token before the previous one expires.
	 *
	 * @param token Valid JWT.
	 * @param awaitDataLoad Optional flag that determines whether the returned promise should wait
	 * for the full initialization of NavVis IVION. Needs to be set true if the login promise is
	 * chained with some API functions. Defaults to false.
	 *
	 * @returns A promise that is resolved after successful login and rejected if e.g. the provided
	 * token is invalid.
	 */
	loginWithToken(token: string, awaitDataLoad?: boolean): Promise<UserEntityInterface>;
	/**
	 * Logs in a user with the provided JWTs, either for local NavVis IVION accounts or e.g. for
	 * OAuth Resource Server if the instance is set up to use one.
	 *
	 * Note that it also removes logout functionality from the UI and that NavVis IVION will not
	 * automatically refresh the token when it is about to expire. Use {@link updateToken} to
	 * apply an updated token before the previous one expires.
	 *
	 * @param accessToken Valid JWT.
	 * @param uploadToken Valid JWT for uploads.
	 * @param awaitDataLoad Optional flag that determines whether the returned promise should wait
	 * for the full initialization of NavVis IVION. Needs to be set true if the login promise is
	 * chained with some API functions. Defaults to false.
	 *
	 * @returns A promise that is resolved after successful login and rejected if e.g. the provided
	 * token is invalid.
	 */
	loginWithTokens(accessToken: string, uploadToken: string, awaitDataLoad?: boolean): Promise<UserEntityInterface>;
	/**
	 * Updates the locally stored JWT access token such that it will be used to authenticate
	 * future requests.
	 * @param token Valid JWT access token.
	 * @param uploadToken Optional, valid JWT for uploads.
	 */
	updateToken(token: string, uploadToken?: string): void;
	/**
	 * Retrieves the locally stored JWT that can be used to authenticate requests.
	 * @returns the locally stored JWT.
	 */
	getToken(): string;
}
export interface SiteRepositoryInterface extends RestRepositoryInterface<SiteInterface> {
	/**
	 * Returns the site that is closest to the specified global coordinate.
	 *
	 * @param location Location of the site in WGS 84
	 * @returns Promise that resolves with the site
	 */
	findByLocation(location: Vector3): Promise<SiteInterface>;
}
export type ActiveSiteSelectedHandler = 
/**
 * Signal handler for active site selected events
 *
 * @param selectedSite The new active site (may be undefined)
 * @param oldSite The previously active site (may be undefined)
 */
(selectedSite: SiteInterface, oldSite: SiteInterface) => void;
/**
 * Service that provides access to the currently active site
 */
export interface SiteServiceInterface {
	/**
	 * The active site. Can be undefined in case no site is active.
	 */
	activeSite: SiteInterface;
	/**
	 * Signal that is emitted when a site is selected.
	 * Also fires (with undefined) when a site is left.
	 */
	activeSiteSelected: Signal<ActiveSiteSelectedHandler>;
	/**
	 * Change the active site to the provided one.
	 * If undefined, the active site is unloaded and the site selection screen is shown.
	 *
	 * @param site Site to load (or undefined)
	 */
	loadSite(site: SiteInterface): Promise<void>;
}
export interface SiteApiInterface {
	readonly repository: SiteRepositoryInterface;
	readonly service: SiteServiceInterface;
}
/**
 * The Mesh API encapsulates object that concerns mesh loading.
 */
export interface MeshApiInterface {
	/**
	 * If provided, the callback will be passed to each resource URL before a request is sent.
	 * The callback may return the original URL, or a new URL to override loading behavior.
	 * This behavior can be used to load assets from .ZIP files, drag-and-drop APIs, and Data URIs.
	 *
	 * @param callback URL modifier callback. Called with url argument, and must return resolved URL.
	 */
	setUrlModifier(callback?: (url: string) => string): void;
	/**
	 * This method sets request headers for instance the authorization token etc.
	 *
	 * @param requestHeader dictionary with headers to set.
	 */
	setRequestHeader(requestHeader: {
		[header: string]: string;
	}): void;
	/**
	 * Given URL path the method will recursively load the .gltf file content.
	 *
	 * @param path URL with .gltf root file.
	 * @param onLoad Called when the mesh is loaded with groups argument.
	 */
	loadScene(path: string, onLoad: (groups: Group[]) => void): void;
}
/**
 * Enum representing the different modes a user can switch to.
 */
export declare enum ModeState {
	NORMAL = "NORMAL",
	DATASET_ALIGNMENT = "DATASET_ALIGNMENT",
	SITE_MODEL_EDITOR = "SITE_MODEL_EDITOR",
	NAV_GRAPH_EDITOR = "NAV_GRAPH_EDITOR",
	DOWNLOAD_POINT_CLOUD = "DOWNLOAD_POINT_CLOUD",
	MARK_AND_MEASURE = "MARK_AND_MEASURE"
}
export interface ModeSwitchServiceInterface {
	/**
	 * Switch to given mode if authorized. Closes current mode and related
	 * toolbox.
	 *
	 * @param name The mode to switch to
	 * @param onClose Callback when the mode is closed
	 */
	switchToMode(name: ModeState, onClose?: () => {}): Promise<void>;
	/**
	 * This method will return the currently available modes considering the site's state (published or draft).
	 * @return Array list of modeState names.
	 */
	getAvailableModes(): ModeState[];
}
/**
 * The Mode API provides access to switch between modes.
 */
export interface ModeApiInterface {
	/**
	 * The mode switch service provides functionality that allows to switch between modes.
	 */
	readonly service: ModeSwitchServiceInterface;
}
/**
 * Service that provides access to publishing workflow actions
 */
export interface PublishingServiceInterface {
	/**
	 * Create a draft for the given site.
	 * @param site The site for which to create a draft
	 */
	createSiteDraft(site: SiteInterface): Promise<SiteInterface>;
	/**
	 * Publish the given draft site, transforming the site in a published one.
	 * @param draftSite The draft site to publish
	 */
	publishDraft(draftSite: SiteInterface): Promise<void>;
	/**
	 * Discard a draft for the given site. This method resets site repository cache and
	 * refreshes users and groups if discard successful.
	 *
	 * @param draftSite The draft site for which to discard a draft
	 */
	discardDraft(draftSite: SiteInterface): Promise<void>;
}
export interface PublishingApiInterface {
	readonly service: PublishingServiceInterface;
}
/**
 * Main API interface which shall contain all sub API objects.
 */
export interface ApiInterface {
	readonly about: AboutApiInterface;
	readonly dataset: DatasetApiInterface;
	readonly image: ImageApiInterface;
	readonly legacyApi: IvionInterface;
	readonly license: LicenseApiInterface;
	readonly lib: ThirdPartyLibraryInterface;
	readonly poi: PoiApiInterface;
	readonly site: SiteApiInterface;
	readonly siteModel: SiteModelApiInterface;
	readonly transform: TransformApiInterface;
	readonly view: ViewApiInterface;
	readonly ui: UiApiInterface;
	readonly routing: RouteApiInterface;
	readonly share: ShareApiInterface;
	readonly auth: AuthApiInterface;
	readonly mesh: MeshApiInterface;
	readonly mode: ModeApiInterface;
	readonly publishing: PublishingApiInterface;
	/**
	 * Checks whether the API feature is enabled for this instance. If not licensed the API can not
	 * be used and will throw errors if attempted. Therefore use this method to check first whether
	 * other API calls will work.
	 */
	isLicensed(): boolean;
	/**
	 * Whether private mode is on or not. If an instance is private, only logged in users will have
	 * access to data.
	 */
	isPrivate(): Promise<boolean>;
}
/**
 * Embed and URL configuration properties.
 *
 * These properties are used to modify the behavior and appearance of NavVis IVION when first loaded.
 *
 */
export interface ConfigurationInterface {
	/**
	 * Base URL of the NavVis IVION instance
	 * @hidden
	 */
	"base_url"?: string;
	/**
	 * HTML to show as extra credits in about box.
	 */
	"info.terms.extra"?: string;
	/**
	 * HTML to show as privacy policy in about box.
	 */
	"info.terms.privacy"?: string;
	/**
	 * Overrides the language settings from browser language, cookie and local
	 * store.
	 * Supported language keys are:
	 * * `cs`: Czech
	 * * `de`: German
	 * * `en`: English
	 * * `fr`: French
	 * * `ja`: Japanese
	 * * `es`: Spanish
	 * * `zh`: Simplified Chinese
	 * * `zh_tw`: Traditional Chinese
	 */
	"lang"?: string;
	/**
	 * JavaScript code to insert into the page, e.g. for adding analytics.
	 */
	"tracking.code"?: string;
	/**
	 * Whether to insert the tracking code.
	 */
	"tracking.enabled"?: boolean;
	/**
	 * Logs a user in with the provided JWT, either for local NavVis IVION accounts or e.g. for
	 * OAuth Resource Server if the instance is set up to use one.
	 *
	 * Note that it also removes logout functionality from the UI and that NavVis IVION will not
	 * automatically refresh the token when it is about to expire. Use api.auth.updateToken(...) to
	 * apply an updated token before the previous one expires.
	 */
	"loginToken"?: string;
	/**
	 * Optional, If provided along with loginToken, used for authorizing uploads with the provided JWT,
	 * either for local NavVis IVION accounts or e.g. for
	 * OAuth Resource Server if the instance is set up to use one.
	 *
	 * When not provided, loginToken will be used.
	 *
	 * Note that it also removes logout functionality from the UI and that NavVis IVION will not
	 * automatically refresh the token when it is about to expire. Use api.auth.updateToken(...) to
	 * apply an updated token before the previous one expires.
	 */
	"uploadToken"?: string;
	/**
	 * Callback that is invoked after data has been loaded and the view has moved to the starting
	 * location.
	 *
	 * @deprecated Do not use this with the NPM API, use getApi().then(callback) instead.
	 */
	"onLoadComplete"?: () => void;
	/**
	 * Callback that is invoked when WebGL initialization has failed.
	 *
	 * @param reason Error message
	 * @deprecated Do not use this with the NPM API, use getApi().catch(callback) instead.
	 */
	"onWebGlFailed"?: (reason: string) => void;
	/**
	 * Whether to automatically show point clouds when no panorama is available. True by default.
	 */
	"allowPointCloudActivation"?: boolean;
}
/**
 * Initial configuration attributes for when a {@link SceneLayerInterface} is instantiated.
 */
export interface SceneLayerConfigInterface {
	/**
	 * Enable or disable visual rendering for the scene's objects.
	 */
	visible?: boolean;
}
/**
 * A Signal where the connect method keeps track of connections
 */
export interface TrackedSignal<CB extends Function> {
	/**
	 * {@link Signal.connect}
	 */
	connect(callback: CB): SignalConnection;
}
declare abstract class AbstractSceneLayer implements SceneLayerInterface {
	view: AbstractViewInterface;
	private scene;
	/**
	 * Container object for all 3D objects of this scene layer
	 */
	protected sceneGroup: Object3D;
	/**
	 * Time in ms to debounce map view rendering by to avoid unnecessary work.
	 */
	protected static readonly ORTHO_DEBOUNCE: number;
	/**
	 * Visibility of the scene layer
	 */
	private _visible;
	/**
	 * If non-null, layer is only visible in that viewport
	 */
	private _targetViewport;
	/**
	 * List of signal connections that will be disconnected automatically when the view is destroyed
	 */
	private signalConnections;
	constructor(view: AbstractViewInterface, scene: Scene, params: SceneLayerConfigInterface);
	/**
	 * Called when the view is destroyed. Override this method and clean up all references to
	 * objects that would prevent garbage collection, e.g., signal handlers and transient fields
	 * that your scene layer may have put on entities.
	 *
	 * This implementation will detach all signal handlers registered by connectToSignal(), remove
	 * the sceneGroup from the scene and set it to undefined.
	 *
	 * Override this method to clean up references  (and call the super class method)
	 */
	onDestroy(): void;
	/**
	 * Called before rendering
	 *
	 * @param camera Camera used to render the view
	 */
	onBeforeRender(camera: Camera): void;
	/**
	 * Called before rendering a viewport. Updates layer visibility depending on viewport and
	 * avoids raycasting objects if {@link #targetViewport} doesn't match the passed viewport.
	 *
	 * Note: If you override this method and change the position, orientation or scale of a mesh,
	 * and you rely on mouse events on the meshes or use getObjectsUnderCursor(),
	 * call this.sceneGroup.updateWorldMatrix(false, true); in your overridden method.
	 *
	 * @param viewport Viewport where rendering takes place
	 */
	onBeforeRenderViewport(viewport: ViewportInterface): void;
	/**
	 * Called after rendering of all viewports
	 *
	 * @param camera Camera used to render the view
	 */
	onAfterRender(camera: Camera): void;
	/**
	 * Called after rendering of a viewport
	 *
	 * @param viewport Viewport where rendering took place
	 */
	onAfterRenderViewport(viewport: ViewportInterface): void;
	/**
	 * Called after the rendering of a scene in a viewport.
	 * @param viewport Viewport where the rendering took place
	 * @param scene The last scene that was rendered.
	 */
	onAfterSceneRenderViewport(viewport: ViewportInterface, scene: Scene): void;
	/**
	 * Called when a location transition is started
	 *
	 * @param event Transition event
	 */
	onTransitionStart(event: TransitionStartEventInterface): void;
	/**
	 * Called after location transition has completed
	 *
	 * @param event Transition event
	 */
	onTransitionEnd(event: TransitionEndEventInterface): void;
	/**
	 * Called shortly after the camera has stopped moving
	 *
	 * @param {Promise<void>} asyncWork Promise which blocks until the {@link AbstractViewInterface}
	 * has completed any asynchronous work, independent of whether it rejects or resolves.
	 */
	onCameraMoveEnd(asyncWork: Promise<void>): void;
	/**
	 * Called shortly after the camera inside the viewport has stopped moving
	 *
	 * @param viewport The viewport where the camera move happened
	 * @param {Promise<void>} asyncWork Promise which blocks until the {@link AbstractViewInterface}
	 * has completed any asynchronous work, independent of whether it rejects or resolves.
	 */
	onViewportCameraMoveEnd(viewport: ViewportInterface, asyncWork: Promise<void>): void;
	/**
	 * Called when a key is pressed down
	 *
	 * @param event Key event data
	 * @returns {boolean} Return true to consume the event, false to pass it on to other layers
	 */
	onKeyDown(event: KeyboardEvent): boolean;
	/**
	 * Called when a key is released
	 *
	 * @param event Key event data
	 * @returns {boolean} Return true to consume the event, false to pass it on to other layers
	 *
	 * @note released keys on a physical keyboard connected to an iOS device do not fire the keyup
	 *     event
	 */
	onKeyUp(event: KeyboardEvent): boolean;
	/**
	 * Called for mouse clicks and taps
	 *
	 * @param pos Mouse position
	 * @param cursorPos Cursor position at time of the mouse click
	 * @returns {boolean} Return true to consume the event, false to pass it on
	 */
	onClick(pos: MouseEventCoordinatesInterface, cursorPos?: Vector3): boolean;
	/**
	 * Called for double clicks and double taps
	 *
	 * @param pos Mouse position
	 * @returns {boolean} Return true to consume the event, false to pass it on
	 */
	onDoubleClick(pos: MouseEventCoordinatesInterface): boolean;
	/**
	 * Called for click-and-hold and touch-and-hold
	 *
	 * @param pos Mouse position
	 * @returns {boolean} Return true to consume the event, false to pass it on
	 */
	onHold(pos: MouseEventCoordinatesInterface): boolean;
	/**
	 * Called when the mouse is moved
	 *
	 * @param pos Mouse position
	 */
	onMouseMove(pos: MouseEventCoordinatesInterface): void;
	/**
	 * Called when the mouse wheel is used
	 *
	 * @param pos Mouse position
	 * @param delta Number of wheel ticks, positive for scrolling down, negative for up
	 * @returns {boolean} Return true to consume the event, false to pass it on
	 */
	onMouseWheel(pos: MouseEventCoordinatesInterface, delta: number): boolean;
	/**
	 * Called when the context menu is about to be shown
	 *
	 * Return context menu items from this method to add them to the context menu. Return undefined
	 * (or do not implement the method) if you do not want to add an entry from the specific layer.
	 * Return false to prevent the context menu from opening.
	 *
	 * @param pos Mouse position
	 * @returns {OnContextMenuResult} List of context menu items
	 */
	onContextMenu(pos: MouseEventCoordinatesInterface): OnContextMenuResult | Promise<OnContextMenuResult>;
	protected isVisibleInViewport(viewport: ViewportInterface): boolean;
	/**
	 * Wrap the provided Signal into a TrackedSignal which keeps track of calls to its connect
	 * method. The connections made through the TrackedSignal will be disconnected automatically
	 * when the scene layer is destroyed.
	 *
	 * @param signal The signal to wrap.
	 * @returns {TrackedSignal} Signal that keeps track of connections made to it.
	 */
	protected trackSignal<CB extends (...args: unknown[]) => unknown>(signal: Signal<CB>): TrackedSignal<CB>;
	get targetViewport(): ViewportInterface;
	set targetViewport(value: ViewportInterface);
	get visible(): boolean;
	set visible(visible: boolean);
	/**
	 * Retrieve the active viewport. This is either the {@link targetViewport} if defined or
	 * otherwise the {@link view}'s default viewport.
	 * <br>
	 * Note: use this over {@link targetViewport} if you just need the active viewport for this
	 * layer and don't care whether a specific one or the default one is specified.
	 */
	getActiveViewport(): ViewportInterface;
	/**
	 * Callback when visible property is changed
	 */
	protected visibilityChanged(): void;
}
/**
 * CustomLayer enables API users to create a scene layer in any view. Creating
 * a subclass that extends CustomLayer can leverage the event handlers deliniated
 * in {@link SceneLayerInterface}.
 */
export declare class CustomLayer extends AbstractSceneLayer {
	view: AbstractViewInterface;
	constructor(view: AbstractViewInterface, config?: SceneLayerConfigInterface);
}
/**
 * Mouse and touch events
 */
export interface MouseEventReceiverInterface {
	/**
	 * Called for mouse clicks and taps
	 *
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @param instanceId The index of the instance if the event occurred on an InstancedMesh.
	 * @returns {boolean} Return true to consume the event, false to pass it on
	 */
	onClick?(pos: MouseEventCoordinatesInterface, instanceId?: number): boolean;
	/**
	 * Called for double clicks and double taps
	 *
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @param instanceId The index of the instance if the event occurred on an InstancedMesh.
	 * @returns {boolean} Return true to consume the event, false to pass it on
	 */
	onDoubleClick?(pos: MouseEventCoordinatesInterface, instanceId?: number): boolean;
	/**
	 * Called for click-and-hold and touch-and-hold
	 *
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @param instanceId The index of the instance if the event occurred on an InstancedMesh.d
	 * @returns {boolean} Return true to consume the event, false to pass it on
	 */
	onHold?(pos: MouseEventCoordinatesInterface, instanceId?: number): boolean;
	/**
	 * Called when the mouse is moved
	 *
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @param {Viewport} viewport The current viewport
	 * @param instanceId The index of the instance if the event occurred on an InstancedMesh.
	 */
	onMouseMove?(pos: MouseEventCoordinatesInterface, viewport: ViewportInterface, instanceId?: number): void;
	/**
	 * Called when the mouse is hovered on the target
	 *
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @param {Viewport} viewport The current viewport
	 * @param instanceId The index of the instance if the event occurred on an InstancedMesh.
	 */
	onMouseOver?(pos: MouseEventCoordinatesInterface, viewport: ViewportInterface, instanceId?: number): void;
	/**
	 * Called when the mouse pointer leaves the target
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @param {Viewport} viewport The current viewport
	 * @param instanceId The index of the instance if the event occurred on an InstancedMesh.
	 */
	onMouseOut?(pos: MouseEventCoordinatesInterface, viewport: ViewportInterface, instanceId?: number): void;
	/**
	 * Called when the mouse wheel is turned
	 * @param {MouseEventCoordinatesInterface} pos Mouse position
	 * @param {number} delta Mouse wheel delta
	 * @param instanceId The index of the instance if the event occurred on an InstancedMesh.
	 * @return {boolean}
	 */
	onMouseWheel?(pos: MouseEventCoordinatesInterface, delta: number, instanceId?: number): boolean;
	/**
	 * Called when the user starts dragging the target
	 * @param {MouseEventCoordinatesInterface} position Mouse position
	 * @param viewport The current viewport
	 * @param instanceId The index of the instance if the event occurred on an InstancedMesh.
	 * @return {boolean}
	 */
	onDragStart?(position: MouseEventCoordinatesInterface, viewport: ViewportInterface, instanceId?: number): boolean;
	/**
	 * Called during dragging
	 * @param {MouseEventCoordinatesInterface} position Mouse position
	 * @param viewport The current viewport
	 * @param instanceId The index of the instance if the event occurred on an InstancedMesh.
	 */
	onDrag?(position: MouseEventCoordinatesInterface, viewport: ViewportInterface, instanceId?: number): void;
	/**
	 * Called when the user releases the mouse button after dragging
	 * @param instanceId The index of the instance if the event occurred on an InstancedMesh.
	 */
	onDragEnd?(position: MouseEventCoordinatesInterface, viewport: ViewportInterface, instanceId?: number): void;
	/**
	 * Called when the user cancels dragging by pressing the ``escape`` key
	 * @param instanceId The index of the instance if the event occurred on an InstancedMesh.
	 */
	onDragCancel?(instanceId?: number): void;
}
export declare enum BlendingMode {
	NoBlending = 0,
	NormalBlending = 1,
	AdditiveBlending = 2,
	SubtractiveBlending = 3,
	MultiplyBlending = 4
}
/**
 * Enum to store the layer panel item names.
 */
export declare enum LayerPanelItemEnum {
	STANDARD = "STANDARD",
	SITE_MODEL = "SITE_MODEL",
	SCAN_DATA = "SCAN_DATA",
	DATASETS = "DATASETS"
}
/**
 * Retrieve the NavVis IVION API from the provided base URL
 *
 * @param baseUrl Base URL of NavVis IVION instance, e.g. https://www.navvis.com/iv.
 * @param config Client configuration parameters.
 *
 * @returns Promise for NavVis IVION API object. The promise resolves once data has been loaded and
 *    the view has been moved to the startup location. If private mode is enabled, the promise
 *    resolves only after a user has logged in. The promise rejects if there is an error during
 *    loading or initialization. The promise also rejects when WebGL is unavailable.
 */
export declare function getApi(baseUrl: string, config?: ConfigurationInterface): Promise<ApiInterface>;

export {};
